# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/device.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1avoltha_protos/device.proto\x12\x06\x64\x65vice\x1a\x19google/protobuf/any.proto\x1a\x1avoltha_protos/common.proto\x1a\x1fvoltha_protos/openflow_13.proto\"\xde\x01\n\nDeviceType\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tvendor_id\x18\x05 \x01(\t\x12\x12\n\nvendor_ids\x18\x06 \x03(\t\x12\x0f\n\x07\x61\x64\x61pter\x18\x02 \x01(\t\x12 \n\x18\x61\x63\x63\x65pts_bulk_flow_update\x18\x03 \x01(\x08\x12\'\n\x1f\x61\x63\x63\x65pts_add_remove_flow_updates\x18\x04 \x01(\x08\x12+\n#accepts_direct_logical_flows_update\x18\x07 \x01(\x08\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x08 \x01(\t\"0\n\x0b\x44\x65viceTypes\x12!\n\x05items\x18\x01 \x03(\x0b\x32\x12.device.DeviceType\"\x9f\x01\n\x08PmConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.device.PmConfig.PmType\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x13\n\x0bsample_freq\x18\x04 \x01(\r\"8\n\x06PmType\x12\x0b\n\x07\x43OUNTER\x10\x00\x12\t\n\x05GAUGE\x10\x01\x12\t\n\x05STATE\x10\x02\x12\x0b\n\x07\x43ONTEXT\x10\x03\"k\n\rPmGroupConfig\x12\x12\n\ngroup_name\x18\x01 \x01(\t\x12\x12\n\ngroup_freq\x18\x02 \x01(\r\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12!\n\x07metrics\x18\x04 \x03(\x0b\x32\x10.device.PmConfig\"\xb1\x01\n\tPmConfigs\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65\x66\x61ult_freq\x18\x02 \x01(\r\x12\x0f\n\x07grouped\x18\x03 \x01(\x08\x12\x15\n\rfreq_override\x18\x04 \x01(\x08\x12%\n\x06groups\x18\x05 \x03(\x0b\x32\x15.device.PmGroupConfig\x12!\n\x07metrics\x18\x06 \x03(\x0b\x32\x10.device.PmConfig\x12\x10\n\x08max_skew\x18\x07 \x01(\r\"\xb5\x01\n\x05Image\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x03 \x01(\r\x12\x18\n\x10install_datetime\x18\x04 \x01(\t\x12\x11\n\tis_active\x18\x05 \x01(\x08\x12\x14\n\x0cis_committed\x18\x06 \x01(\x08\x12\x10\n\x08is_valid\x18\x07 \x01(\x08\x12\x0b\n\x03url\x18\x08 \x01(\t\x12\x0e\n\x06vendor\x18\t \x01(\t\x12\r\n\x05\x63rc32\x18\n \x01(\r\"\xe1\x06\n\rImageDownload\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x0b\n\x03\x63rc\x18\x04 \x01(\r\x12@\n\x0e\x64ownload_state\x18\x05 \x01(\x0e\x32(.device.ImageDownload.ImageDownloadState\x12\x15\n\rimage_version\x18\x06 \x01(\t\x12\x18\n\x10\x64ownloaded_bytes\x18\x07 \x01(\r\x12@\n\x06reason\x18\x08 \x01(\x0e\x32\x30.device.ImageDownload.ImageDownloadFailureReason\x12\x17\n\x0f\x61\x64\x64itional_info\x18\t \x01(\t\x12\x13\n\x0bsave_config\x18\n \x01(\x08\x12\x11\n\tlocal_dir\x18\x0b \x01(\t\x12=\n\x0bimage_state\x18\x0c \x01(\x0e\x32(.device.ImageDownload.ImageActivateState\x12\x11\n\tfile_size\x18\r \x01(\r\"\xb7\x01\n\x12ImageDownloadState\x12\x14\n\x10\x44OWNLOAD_UNKNOWN\x10\x00\x12\x16\n\x12\x44OWNLOAD_SUCCEEDED\x10\x01\x12\x16\n\x12\x44OWNLOAD_REQUESTED\x10\x02\x12\x14\n\x10\x44OWNLOAD_STARTED\x10\x03\x12\x13\n\x0f\x44OWNLOAD_FAILED\x10\x04\x12\x18\n\x14\x44OWNLOAD_UNSUPPORTED\x10\x05\x12\x16\n\x12\x44OWNLOAD_CANCELLED\x10\x06\"\x86\x01\n\x1aImageDownloadFailureReason\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x0f\n\x0bINVALID_URL\x10\x01\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\x02\x12\x16\n\x12INSUFFICIENT_SPACE\x10\x03\x12\x11\n\rUNKNOWN_ERROR\x10\x04\x12\r\n\tCANCELLED\x10\x05\"\x8c\x01\n\x12ImageActivateState\x12\x11\n\rIMAGE_UNKNOWN\x10\x00\x12\x12\n\x0eIMAGE_INACTIVE\x10\x01\x12\x14\n\x10IMAGE_ACTIVATING\x10\x02\x12\x10\n\x0cIMAGE_ACTIVE\x10\x03\x12\x13\n\x0fIMAGE_REVERTING\x10\x04\x12\x12\n\x0eIMAGE_REVERTED\x10\x05:\x02\x18\x01\":\n\x0eImageDownloads\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.device.ImageDownload:\x02\x18\x01\"&\n\x06Images\x12\x1c\n\x05image\x18\x01 \x03(\x0b\x32\r.device.Image\"u\n\x08OnuImage\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\nisCommited\x18\x02 \x01(\x08\x12\x10\n\x08isActive\x18\x03 \x01(\x08\x12\x0f\n\x07isValid\x18\x04 \x01(\x08\x12\x13\n\x0bproductCode\x18\x05 \x01(\t\x12\x0c\n\x04hash\x18\x06 \x01(\t\",\n\tOnuImages\x12\x1f\n\x05items\x18\x01 \x03(\x0b\x32\x10.device.OnuImage\"M\n\x10\x44\x65viceImageState\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12&\n\nimageState\x18\x02 \x01(\x0b\x32\x12.device.ImageState\"\xd6\x07\n\nImageState\x12\x0f\n\x07version\x18\x01 \x01(\t\x12=\n\x0e\x64ownload_state\x18\x02 \x01(\x0e\x32%.device.ImageState.ImageDownloadState\x12\x35\n\x06reason\x18\x03 \x01(\x0e\x32%.device.ImageState.ImageFailureReason\x12<\n\x0bimage_state\x18\x04 \x01(\x0e\x32\'.device.ImageState.ImageActivationState\"\xd0\x01\n\x12ImageDownloadState\x12\x14\n\x10\x44OWNLOAD_UNKNOWN\x10\x00\x12\x16\n\x12\x44OWNLOAD_SUCCEEDED\x10\x01\x12\x16\n\x12\x44OWNLOAD_REQUESTED\x10\x02\x12\x14\n\x10\x44OWNLOAD_STARTED\x10\x03\x12\x13\n\x0f\x44OWNLOAD_FAILED\x10\x04\x12\x18\n\x14\x44OWNLOAD_UNSUPPORTED\x10\x05\x12\x17\n\x13\x44OWNLOAD_CANCELLING\x10\x06\x12\x16\n\x12\x44OWNLOAD_CANCELLED\x10\x07\"\xf4\x01\n\x12ImageFailureReason\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x0f\n\x0bINVALID_URL\x10\x01\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\x02\x12\x16\n\x12INSUFFICIENT_SPACE\x10\x03\x12\x11\n\rUNKNOWN_ERROR\x10\x04\x12\x18\n\x14\x43\x41NCELLED_ON_REQUEST\x10\x05\x12\x1a\n\x16\x43\x41NCELLED_ON_ONU_STATE\x10\x06\x12\x1a\n\x16VENDOR_DEVICE_MISMATCH\x10\x07\x12\x17\n\x13OMCI_TRANSFER_ERROR\x10\x08\x12\x18\n\x14IMAGE_REFUSED_BY_ONU\x10\t\"\xb8\x02\n\x14ImageActivationState\x12\x11\n\rIMAGE_UNKNOWN\x10\x00\x12\x12\n\x0eIMAGE_INACTIVE\x10\x01\x12\x14\n\x10IMAGE_ACTIVATING\x10\x02\x12\x10\n\x0cIMAGE_ACTIVE\x10\x03\x12\x14\n\x10IMAGE_COMMITTING\x10\x04\x12\x13\n\x0fIMAGE_COMMITTED\x10\x05\x12\x1d\n\x19IMAGE_ACTIVATION_ABORTING\x10\x06\x12\x1c\n\x18IMAGE_ACTIVATION_ABORTED\x10\x07\x12\x19\n\x15IMAGE_COMMIT_ABORTING\x10\x08\x12\x18\n\x14IMAGE_COMMIT_ABORTED\x10\t\x12\x15\n\x11IMAGE_DOWNLOADING\x10\n\x12\x1d\n\x19IMAGE_DOWNLOADING_ABORTED\x10\x0b\"\xa2\x04\n\x04Port\x12\x0f\n\x07port_no\x18\x01 \x01(\r\x12\r\n\x05label\x18\x02 \x01(\t\x12#\n\x04type\x18\x03 \x01(\x0e\x32\x15.device.Port.PortType\x12-\n\x0b\x61\x64min_state\x18\x05 \x01(\x0e\x32\x18.common.AdminState.Types\x12-\n\x0boper_status\x18\x06 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x11\n\tdevice_id\x18\x07 \x01(\t\x12$\n\x05peers\x18\x08 \x03(\x0b\x32\x15.device.Port.PeerPort\x12\x12\n\nrx_packets\x18\t \x01(\x06\x12\x10\n\x08rx_bytes\x18\n \x01(\x06\x12\x11\n\trx_errors\x18\x0b \x01(\x06\x12\x12\n\ntx_packets\x18\x0c \x01(\x06\x12\x10\n\x08tx_bytes\x18\r \x01(\x06\x12\x11\n\ttx_errors\x18\x0e \x01(\x06\x12\'\n\x08ofp_port\x18\x0f \x01(\x0b\x32\x15.openflow_13.ofp_port\x1a.\n\x08PeerPort\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0f\n\x07port_no\x18\x02 \x01(\r\"s\n\x08PortType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x10\n\x0c\x45THERNET_NNI\x10\x01\x12\x10\n\x0c\x45THERNET_UNI\x10\x02\x12\x0b\n\x07PON_OLT\x10\x03\x12\x0b\n\x07PON_ONU\x10\x04\x12\r\n\tVENET_OLT\x10\x05\x12\r\n\tVENET_ONU\x10\x06\"$\n\x05Ports\x12\x1b\n\x05items\x18\x01 \x03(\x0b\x32\x0c.device.Port\"\xbf\x07\n\x06\x44\x65vice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04root\x18\x03 \x01(\x08\x12\x11\n\tparent_id\x18\x04 \x01(\t\x12\x16\n\x0eparent_port_no\x18\x14 \x01(\r\x12\x0e\n\x06vendor\x18\x05 \x01(\t\x12\r\n\x05model\x18\x06 \x01(\t\x12\x18\n\x10hardware_version\x18\x07 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x08 \x01(\t\x12\x1e\n\x06images\x18\t \x01(\x0b\x32\x0e.device.Images\x12\x15\n\rserial_number\x18\n \x01(\t\x12\x11\n\tvendor_id\x18\x18 \x01(\t\x12\x18\n\x10\x61\x64\x61pter_endpoint\x18\x19 \x01(\t\x12\x0c\n\x04vlan\x18\x0c \x01(\r\x12\x13\n\x0bmac_address\x18\r \x01(\t\x12\x16\n\x0cipv4_address\x18\x0e \x01(\tH\x00\x12\x16\n\x0cipv6_address\x18\x0f \x01(\tH\x00\x12\x17\n\rhost_and_port\x18\x15 \x01(\tH\x00\x12\x12\n\nextra_args\x18\x17 \x01(\t\x12\x32\n\rproxy_address\x18\x13 \x01(\x0b\x32\x1b.device.Device.ProxyAddress\x12-\n\x0b\x61\x64min_state\x18\x10 \x01(\x0e\x32\x18.common.AdminState.Types\x12-\n\x0boper_status\x18\x11 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x0e\n\x06reason\x18\x16 \x01(\t\x12\x33\n\x0e\x63onnect_status\x18\x12 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12$\n\x06\x63ustom\x18@ \x01(\x0b\x32\x14.google.protobuf.Any\x12&\n\npm_configs\x18\x83\x01 \x01(\x0b\x32\x11.device.PmConfigs\x12/\n\x0fimage_downloads\x18\x85\x01 \x03(\x0b\x32\x15.device.ImageDownload\x1a\xc3\x01\n\x0cProxyAddress\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x02 \x01(\t\x12\x12\n\nchannel_id\x18\x03 \x01(\r\x12\x18\n\x10\x63hannel_group_id\x18\x04 \x01(\r\x12\x1b\n\x13\x63hannel_termination\x18\x05 \x01(\t\x12\x0e\n\x06onu_id\x18\x06 \x01(\r\x12\x16\n\x0eonu_session_id\x18\x07 \x01(\r\x12\x18\n\x10\x61\x64\x61pter_endpoint\x18\x08 \x01(\tB\t\n\x07\x61\x64\x64ressJ\x04\x08\x0b\x10\x0c\"\x8d\x01\n\x1a\x44\x65viceImageDownloadRequest\x12\x1d\n\tdevice_id\x18\x01 \x03(\x0b\x32\n.common.ID\x12\x1c\n\x05image\x18\x02 \x01(\x0b\x32\r.device.Image\x12\x19\n\x11\x61\x63tivateOnSuccess\x18\x03 \x01(\x08\x12\x17\n\x0f\x63ommitOnSuccess\x18\x04 \x01(\x08\"]\n\x12\x44\x65viceImageRequest\x12\x1d\n\tdevice_id\x18\x01 \x03(\x0b\x32\n.common.ID\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x17\n\x0f\x63ommitOnSuccess\x18\x03 \x01(\x08\"L\n\x13\x44\x65viceImageResponse\x12\x35\n\x13\x64\x65vice_image_states\x18\x01 \x03(\x0b\x32\x18.device.DeviceImageState\"\x9d\x01\n\x10SelfTestResponse\x12\x37\n\x06result\x18\x01 \x01(\x0e\x32\'.device.SelfTestResponse.SelfTestResult\"P\n\x0eSelfTestResult\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x11\n\rNOT_SUPPORTED\x10\x02\x12\x11\n\rUNKNOWN_ERROR\x10\x03\"(\n\x07\x44\x65vices\x12\x1d\n\x05items\x18\x01 \x03(\x0b\x32\x0e.device.Device\"\xb6\x02\n\x14SimulateAlarmRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tindicator\x18\x02 \x01(\t\x12\x0f\n\x07intf_id\x18\x03 \x01(\t\x12\x16\n\x0eport_type_name\x18\x04 \x01(\t\x12\x15\n\ronu_device_id\x18\x05 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x06 \x01(\x05\x12\r\n\x05\x64rift\x18\x07 \x01(\x05\x12\x0f\n\x07new_eqd\x18\x08 \x01(\x05\x12\x19\n\x11onu_serial_number\x18\t \x01(\t\x12=\n\toperation\x18\n \x01(\x0e\x32*.device.SimulateAlarmRequest.OperationType\"%\n\rOperationType\x12\t\n\x05RAISE\x10\x00\x12\t\n\x05\x43LEAR\x10\x01\"o\n\x17OnuSerialNumberOnOLTPon\x12!\n\rolt_device_id\x18\x01 \x01(\x0b\x32\n.common.ID\x12\x1a\n\x04port\x18\x02 \x01(\x0b\x32\x0c.device.Port\x12\x15\n\rserial_number\x18\x03 \x01(\t\"n\n\x0cUpdateDevice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0cipv4_address\x18\x02 \x01(\tH\x00\x12\x16\n\x0cipv6_address\x18\x03 \x01(\tH\x00\x12\x17\n\rhost_and_port\x18\x04 \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ressBZ\n\x1aorg.opencord.voltha.deviceB\x0cVolthaDeviceZ.github.com/opencord/voltha-protos/v5/go/volthab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.device_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032org.opencord.voltha.deviceB\014VolthaDeviceZ.github.com/opencord/voltha-protos/v5/go/voltha'
  _globals['_IMAGEDOWNLOAD']._options = None
  _globals['_IMAGEDOWNLOAD']._serialized_options = b'\030\001'
  _globals['_IMAGEDOWNLOADS']._options = None
  _globals['_IMAGEDOWNLOADS']._serialized_options = b'\030\001'
  _globals['_DEVICETYPE']._serialized_start=127
  _globals['_DEVICETYPE']._serialized_end=349
  _globals['_DEVICETYPES']._serialized_start=351
  _globals['_DEVICETYPES']._serialized_end=399
  _globals['_PMCONFIG']._serialized_start=402
  _globals['_PMCONFIG']._serialized_end=561
  _globals['_PMCONFIG_PMTYPE']._serialized_start=505
  _globals['_PMCONFIG_PMTYPE']._serialized_end=561
  _globals['_PMGROUPCONFIG']._serialized_start=563
  _globals['_PMGROUPCONFIG']._serialized_end=670
  _globals['_PMCONFIGS']._serialized_start=673
  _globals['_PMCONFIGS']._serialized_end=850
  _globals['_IMAGE']._serialized_start=853
  _globals['_IMAGE']._serialized_end=1034
  _globals['_IMAGEDOWNLOAD']._serialized_start=1037
  _globals['_IMAGEDOWNLOAD']._serialized_end=1902
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE']._serialized_start=1435
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADSTATE']._serialized_end=1618
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON']._serialized_start=1621
  _globals['_IMAGEDOWNLOAD_IMAGEDOWNLOADFAILUREREASON']._serialized_end=1755
  _globals['_IMAGEDOWNLOAD_IMAGEACTIVATESTATE']._serialized_start=1758
  _globals['_IMAGEDOWNLOAD_IMAGEACTIVATESTATE']._serialized_end=1898
  _globals['_IMAGEDOWNLOADS']._serialized_start=1904
  _globals['_IMAGEDOWNLOADS']._serialized_end=1962
  _globals['_IMAGES']._serialized_start=1964
  _globals['_IMAGES']._serialized_end=2002
  _globals['_ONUIMAGE']._serialized_start=2004
  _globals['_ONUIMAGE']._serialized_end=2121
  _globals['_ONUIMAGES']._serialized_start=2123
  _globals['_ONUIMAGES']._serialized_end=2167
  _globals['_DEVICEIMAGESTATE']._serialized_start=2169
  _globals['_DEVICEIMAGESTATE']._serialized_end=2246
  _globals['_IMAGESTATE']._serialized_start=2249
  _globals['_IMAGESTATE']._serialized_end=3231
  _globals['_IMAGESTATE_IMAGEDOWNLOADSTATE']._serialized_start=2461
  _globals['_IMAGESTATE_IMAGEDOWNLOADSTATE']._serialized_end=2669
  _globals['_IMAGESTATE_IMAGEFAILUREREASON']._serialized_start=2672
  _globals['_IMAGESTATE_IMAGEFAILUREREASON']._serialized_end=2916
  _globals['_IMAGESTATE_IMAGEACTIVATIONSTATE']._serialized_start=2919
  _globals['_IMAGESTATE_IMAGEACTIVATIONSTATE']._serialized_end=3231
  _globals['_PORT']._serialized_start=3234
  _globals['_PORT']._serialized_end=3780
  _globals['_PORT_PEERPORT']._serialized_start=3617
  _globals['_PORT_PEERPORT']._serialized_end=3663
  _globals['_PORT_PORTTYPE']._serialized_start=3665
  _globals['_PORT_PORTTYPE']._serialized_end=3780
  _globals['_PORTS']._serialized_start=3782
  _globals['_PORTS']._serialized_end=3818
  _globals['_DEVICE']._serialized_start=3821
  _globals['_DEVICE']._serialized_end=4780
  _globals['_DEVICE_PROXYADDRESS']._serialized_start=4568
  _globals['_DEVICE_PROXYADDRESS']._serialized_end=4763
  _globals['_DEVICEIMAGEDOWNLOADREQUEST']._serialized_start=4783
  _globals['_DEVICEIMAGEDOWNLOADREQUEST']._serialized_end=4924
  _globals['_DEVICEIMAGEREQUEST']._serialized_start=4926
  _globals['_DEVICEIMAGEREQUEST']._serialized_end=5019
  _globals['_DEVICEIMAGERESPONSE']._serialized_start=5021
  _globals['_DEVICEIMAGERESPONSE']._serialized_end=5097
  _globals['_SELFTESTRESPONSE']._serialized_start=5100
  _globals['_SELFTESTRESPONSE']._serialized_end=5257
  _globals['_SELFTESTRESPONSE_SELFTESTRESULT']._serialized_start=5177
  _globals['_SELFTESTRESPONSE_SELFTESTRESULT']._serialized_end=5257
  _globals['_DEVICES']._serialized_start=5259
  _globals['_DEVICES']._serialized_end=5299
  _globals['_SIMULATEALARMREQUEST']._serialized_start=5302
  _globals['_SIMULATEALARMREQUEST']._serialized_end=5612
  _globals['_SIMULATEALARMREQUEST_OPERATIONTYPE']._serialized_start=5575
  _globals['_SIMULATEALARMREQUEST_OPERATIONTYPE']._serialized_end=5612
  _globals['_ONUSERIALNUMBERONOLTPON']._serialized_start=5614
  _globals['_ONUSERIALNUMBERONOLTPON']._serialized_end=5725
  _globals['_UPDATEDEVICE']._serialized_start=5727
  _globals['_UPDATEDEVICE']._serialized_end=5837
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voip_system_profile.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'voltha_protos/voip_system_profile.proto\x12\x13voip_system_profile\x1a\x1cgoogle/api/annotations.proto\"j\n\x18VoipSystemProfileRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x11voipSystemProfile\x18\x02 \x01(\x0b\x32&.voip_system_profile.VoipSystemProfile\"{\n\x11VoipSystemProfile\x12\x31\n\tsipConfig\x18\x01 \x01(\x0b\x32\x1e.voip_system_profile.SipConfig\x12\x33\n\nvoipConfig\x18\x02 \x01(\x0b\x32\x1f.voip_system_profile.VoipConfig\"\xab\x03\n\nVoipConfig\x12\x37\n\x0cipHostConfig\x18\x01 \x01(\x0b\x32!.voip_system_profile.IpHostConfig\x12\x37\n\x0ctcpUdpConfig\x18\x02 \x01(\x0b\x32!.voip_system_profile.TcpUdpConfig\x12\x37\n\x0cvoipVoiceCtp\x18\x03 \x01(\x0b\x32!.voip_system_profile.VoipVoiceCtp\x12?\n\x10voipMediaProfile\x18\x04 \x01(\x0b\x32%.voip_system_profile.VoipMediaProfile\x12\x45\n\x13voiceServiceProfile\x18\x05 \x01(\x0b\x32(.voip_system_profile.VoiceServiceProfile\x12\x33\n\nrtpProfile\x18\x06 \x01(\x0b\x32\x1f.voip_system_profile.RtpProfile\x12\x35\n\x0bpptpPotsUni\x18\x07 \x01(\x0b\x32 .voip_system_profile.PptpPotsUni\"\xaf\x01\n\x0cIpHostConfig\x12\x11\n\tipOptions\x18\x01 \x01(\r\x12\x15\n\ronuIdentifier\x18\x02 \x01(\t\x12\x11\n\tipAddress\x18\x03 \x01(\t\x12\x0c\n\x04mask\x18\x04 \x01(\t\x12\x0f\n\x07gateway\x18\x05 \x01(\t\x12\x12\n\nprimaryDns\x18\x06 \x01(\t\x12\x14\n\x0csecondaryDns\x18\x07 \x01(\t\x12\x19\n\x11relayAgentOptions\x18\x08 \x01(\t\"2\n\x0cTcpUdpConfig\x12\x10\n\x08protocol\x18\x01 \x01(\r\x12\x10\n\x08tosField\x18\x02 \x01(\t\"&\n\x0cVoipVoiceCtp\x12\x16\n\x0esignallingCode\x18\x01 \x01(\r\"\x8c\x03\n\x10VoipMediaProfile\x12\x0f\n\x07\x66\x61xMode\x18\x01 \x01(\r\x12\x17\n\x0f\x63odecSelection1\x18\x02 \x01(\r\x12\x1e\n\x16packetPeriodSelection1\x18\x03 \x01(\r\x12\x1b\n\x13silenceSuppression1\x18\x04 \x01(\r\x12\x17\n\x0f\x63odecSelection2\x18\x05 \x01(\r\x12\x1e\n\x16packetPeriodSelection2\x18\x06 \x01(\r\x12\x1b\n\x13silenceSuppression2\x18\x07 \x01(\r\x12\x17\n\x0f\x63odecSelection3\x18\x08 \x01(\r\x12\x1e\n\x16packetPeriodSelection3\x18\t \x01(\r\x12\x1b\n\x13silenceSuppression3\x18\n \x01(\r\x12\x17\n\x0f\x63odecSelection4\x18\x0b \x01(\r\x12\x1e\n\x16packetPeriodSelection4\x18\x0c \x01(\r\x12\x1b\n\x13silenceSuppression4\x18\r \x01(\r\x12\x0f\n\x07oobDtmf\x18\x0e \x01(\r\"\xe4\x01\n\x13VoiceServiceProfile\x12\x18\n\x10\x61nnouncementType\x18\x01 \x01(\r\x12\x14\n\x0cjitterTarget\x18\x02 \x01(\r\x12\x17\n\x0fjitterBufferMax\x18\x03 \x01(\r\x12\x15\n\rechoCancelInd\x18\x04 \x01(\x08\x12\x1b\n\x13pstnProtocolVariant\x18\x05 \x01(\r\x12\x17\n\x0f\x64tmfDigitLevels\x18\x06 \x01(\r\x12\x19\n\x11\x64tmfDigitDuration\x18\x07 \x01(\r\x12\x1c\n\x14hookFlashMinimumTime\x18\x08 \x01(\r\"\x9e\x01\n\nRtpProfile\x12\x14\n\x0clocalPortMin\x18\x01 \x01(\r\x12\x14\n\x0clocalPortMax\x18\x02 \x01(\r\x12\x10\n\x08\x64scpMark\x18\x03 \x01(\t\x12\x17\n\x0fpiggyBackEvents\x18\x04 \x01(\r\x12\x12\n\ntoneEvents\x18\x05 \x01(\r\x12\x12\n\ndtmfEvents\x18\x06 \x01(\r\x12\x11\n\tcasEvents\x18\x07 \x01(\r\"\xcc\x01\n\x0bPptpPotsUni\x12\x0b\n\x03\x61rc\x18\x01 \x01(\t\x12\x13\n\x0b\x61rcInterval\x18\x02 \x01(\t\x12\x11\n\timpedance\x18\x03 \x01(\r\x12\x18\n\x10transmissionPath\x18\x04 \x01(\r\x12\x0e\n\x06rxGain\x18\x05 \x01(\x11\x12\x0e\n\x06txGain\x18\x06 \x01(\x11\x12\x18\n\x10potsHoldOverTime\x18\x07 \x01(\r\x12\x1a\n\x12nominalFeedVoltage\x18\x08 \x01(\r\x12\x18\n\x10lossOfSoftSwitch\x18\t \x01(\r\"\xe6\x02\n\tSipConfig\x12\x35\n\x0bsipUserData\x18\x01 \x01(\x0b\x32 .voip_system_profile.SipUserData\x12;\n\x0esipAgentConfig\x18\x02 \x01(\x0b\x32#.voip_system_profile.SipAgentConfig\x12=\n\x0fnetworkDialPlan\x18\x03 \x01(\x0b\x32$.voip_system_profile.NetworkDialPlan\x12K\n\x16voipFeatureAccessCodes\x18\x04 \x01(\x0b\x32+.voip_system_profile.VoipFeatureAccessCodes\x12Y\n\x1dvoipApplicationServiceProfile\x18\x05 \x01(\x0b\x32\x32.voip_system_profile.VoipApplicationServiceProfile\"\xdd\x01\n\x0bSipUserData\x12\x13\n\x0buserPartAor\x18\x01 \x01(\t\x12\x45\n\x13usernameAndPassword\x18\x02 \x01(\x0b\x32(.voip_system_profile.UsernameAndPassword\x12\x1d\n\x15voicemailServerSipUri\x18\x03 \x01(\t\x12+\n#voicemailSubscriptionExpirationTime\x18\x04 \x01(\x05\x12\x14\n\x0creleaseTimer\x18\x05 \x01(\x05\x12\x10\n\x08rohTimer\x18\x06 \x01(\x05\"\xd9\x02\n\x0eSipAgentConfig\x12\x1c\n\x14outboundProxyAddress\x18\x01 \x01(\t\x12\x15\n\rprimarySipDns\x18\x02 \x01(\t\x12\x17\n\x0fsecondarySipDns\x18\x03 \x01(\t\x12\x15\n\rsipRegExpTime\x18\x04 \x01(\x05\x12\x1d\n\x15sipReregHeadStartTime\x18\x05 \x01(\x05\x12\x14\n\x0cSipRegistrar\x18\x06 \x01(\t\x12\x12\n\nsoftSwitch\x18\x07 \x01(\t\x12?\n\x10sipResponseTable\x18\x08 \x01(\x0b\x32%.voip_system_profile.SipResponseTable\x12 \n\x18sipOptionTransmitControl\x18\t \x01(\x08\x12\x14\n\x0csipUriFormat\x18\n \x01(\t\x12 \n\x18redundantSipAgentPointer\x18\x0b \x01(\t\"\x9d\x01\n\x0fNetworkDialPlan\x12\x1b\n\x13\x63riticalDialTimeout\x18\x01 \x01(\r\x12\x1a\n\x12partialDialTimeout\x18\x02 \x01(\r\x12\x16\n\x0e\x64ialPlanFormat\x18\x03 \x01(\r\x12\x39\n\rdialPlanTable\x18\x04 \x01(\x0b\x32\".voip_system_profile.DialPlanTable\"/\n\x13UsernameAndPassword\x12\x18\n\x10validationScheme\x18\x01 \x01(\x05\"N\n\x10SipResponseTable\x12\x17\n\x0fsipResponseCode\x18\x01 \x01(\t\x12\x0c\n\x04tone\x18\x02 \x01(\t\x12\x13\n\x0btextMessage\x18\x03 \x01(\t\"h\n\rDialPlanTable\x12\x12\n\ndialPlanId\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\r\x12\x15\n\rdialPlanToken\x18\x03 \x01(\t\x12\x1c\n\x14\x64ialPlanTableMaxSize\x18\x04 \x01(\r\"\xe5\x02\n\x16VoipFeatureAccessCodes\x12\x19\n\x11\x63\x61ncelCallWaiting\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61llHold\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61llPark\x18\x03 \x01(\t\x12\x18\n\x10\x63\x61llerIdActivate\x18\x04 \x01(\t\x12\x1a\n\x12\x63\x61llerIdDeactivate\x18\x05 \x01(\t\x12\x1e\n\x16\x64oNotDisturbActivation\x18\x06 \x01(\t\x12 \n\x18\x64oNotDisturbDeactivation\x18\x07 \x01(\t\x12\x1d\n\x15\x64oNotDisturbPinChange\x18\x08 \x01(\t\x12\x1e\n\x16\x65mergencyServiceNumber\x18\t \x01(\t\x12\x17\n\x0fintercomService\x18\n \x01(\t\x12\x1e\n\x16unattendedCallTransfer\x18\x0b \x01(\t\x12\x1c\n\x14\x61ttendedCallTransfer\x18\x0c \x01(\t\"\xbf\x02\n\x1dVoipApplicationServiceProfile\x12\x13\n\x0b\x63idFeatures\x18\x01 \x01(\r\x12\x1b\n\x13\x63\x61llWaitingFeatures\x18\x02 \x01(\r\x12&\n\x1e\x63\x61llProgressOrTransferFeatures\x18\x03 \x01(\r\x12 \n\x18\x63\x61llPresentationFeatures\x18\x04 \x01(\r\x12\x1c\n\x14\x64irectConnectFeature\x18\x05 \x01(\r\x12\x1f\n\x17\x64irectConnectUriPointer\x18\x06 \x01(\t\x12\"\n\x1a\x62ridgedLineAgentUriPointer\x18\x07 \x01(\t\x12#\n\x1b\x63onferenceFactoryUriPointer\x18\x08 \x01(\t\x12\x1a\n\x12\x64ialToneDelayTimer\x18\t \x01(\rBf\n\'org.opencord.voltha.voip_system_profileZ;github.com/opencord/voltha-protos/v5/go/voip_system_profileb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.voip_system_profile_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'org.opencord.voltha.voip_system_profileZ;github.com/opencord/voltha-protos/v5/go/voip_system_profile'
  _globals['_VOIPSYSTEMPROFILEREQUEST']._serialized_start=94
  _globals['_VOIPSYSTEMPROFILEREQUEST']._serialized_end=200
  _globals['_VOIPSYSTEMPROFILE']._serialized_start=202
  _globals['_VOIPSYSTEMPROFILE']._serialized_end=325
  _globals['_VOIPCONFIG']._serialized_start=328
  _globals['_VOIPCONFIG']._serialized_end=755
  _globals['_IPHOSTCONFIG']._serialized_start=758
  _globals['_IPHOSTCONFIG']._serialized_end=933
  _globals['_TCPUDPCONFIG']._serialized_start=935
  _globals['_TCPUDPCONFIG']._serialized_end=985
  _globals['_VOIPVOICECTP']._serialized_start=987
  _globals['_VOIPVOICECTP']._serialized_end=1025
  _globals['_VOIPMEDIAPROFILE']._serialized_start=1028
  _globals['_VOIPMEDIAPROFILE']._serialized_end=1424
  _globals['_VOICESERVICEPROFILE']._serialized_start=1427
  _globals['_VOICESERVICEPROFILE']._serialized_end=1655
  _globals['_RTPPROFILE']._serialized_start=1658
  _globals['_RTPPROFILE']._serialized_end=1816
  _globals['_PPTPPOTSUNI']._serialized_start=1819
  _globals['_PPTPPOTSUNI']._serialized_end=2023
  _globals['_SIPCONFIG']._serialized_start=2026
  _globals['_SIPCONFIG']._serialized_end=2384
  _globals['_SIPUSERDATA']._serialized_start=2387
  _globals['_SIPUSERDATA']._serialized_end=2608
  _globals['_SIPAGENTCONFIG']._serialized_start=2611
  _globals['_SIPAGENTCONFIG']._serialized_end=2956
  _globals['_NETWORKDIALPLAN']._serialized_start=2959
  _globals['_NETWORKDIALPLAN']._serialized_end=3116
  _globals['_USERNAMEANDPASSWORD']._serialized_start=3118
  _globals['_USERNAMEANDPASSWORD']._serialized_end=3165
  _globals['_SIPRESPONSETABLE']._serialized_start=3167
  _globals['_SIPRESPONSETABLE']._serialized_end=3245
  _globals['_DIALPLANTABLE']._serialized_start=3247
  _globals['_DIALPLANTABLE']._serialized_end=3351
  _globals['_VOIPFEATUREACCESSCODES']._serialized_start=3354
  _globals['_VOIPFEATUREACCESSCODES']._serialized_end=3711
  _globals['_VOIPAPPLICATIONSERVICEPROFILE']._serialized_start=3714
  _globals['_VOIPAPPLICATIONSERVICEPROFILE']._serialized_end=4033
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/openolt.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2
from voltha_protos import ext_config_pb2 as voltha__protos_dot_ext__config__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bvoltha_protos/openolt.proto\x12\x07openolt\x1a\x1cgoogle/api/annotations.proto\x1a voltha_protos/tech_profile.proto\x1a\x1evoltha_protos/ext_config.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1avoltha_protos/common.proto\"\xde\x04\n\nIndication\x12)\n\x07olt_ind\x18\x01 \x01(\x0b\x32\x16.openolt.OltIndicationH\x00\x12+\n\x08intf_ind\x18\x02 \x01(\x0b\x32\x17.openolt.IntfIndicationH\x00\x12\x34\n\rintf_oper_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.IntfOperIndicationH\x00\x12\x32\n\x0conu_disc_ind\x18\x04 \x01(\x0b\x32\x1a.openolt.OnuDiscIndicationH\x00\x12)\n\x07onu_ind\x18\x05 \x01(\x0b\x32\x16.openolt.OnuIndicationH\x00\x12+\n\x08omci_ind\x18\x06 \x01(\x0b\x32\x17.openolt.OmciIndicationH\x00\x12,\n\x07pkt_ind\x18\x07 \x01(\x0b\x32\x19.openolt.PacketIndicationH\x00\x12,\n\nport_stats\x18\x08 \x01(\x0b\x32\x16.common.PortStatisticsH\x00\x12-\n\nflow_stats\x18\t \x01(\x0b\x32\x17.openolt.FlowStatisticsH\x00\x12-\n\talarm_ind\x18\n \x01(\x0b\x32\x18.openolt.AlarmIndicationH\x00\x12:\n\x10onu_disabled_ind\x18\x0b \x01(\x0b\x32\x1e.openolt.OnuDisabledIndicationH\x00\x12\x38\n\x0fonu_enabled_ind\x18\x0c \x01(\x0b\x32\x1d.openolt.OnuEnabledIndicationH\x00\x42\x06\n\x04\x64\x61ta\"\xf5\n\n\x0f\x41larmIndication\x12)\n\x07los_ind\x18\x01 \x01(\x0b\x32\x16.openolt.LosIndicationH\x00\x12\x36\n\x0e\x64ying_gasp_ind\x18\x02 \x01(\x0b\x32\x1c.openolt.DyingGaspIndicationH\x00\x12\x34\n\ronu_alarm_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.OnuAlarmIndicationH\x00\x12\x44\n\x14onu_startup_fail_ind\x18\x04 \x01(\x0b\x32$.openolt.OnuStartupFailureIndicationH\x00\x12\x45\n\x16onu_signal_degrade_ind\x18\x05 \x01(\x0b\x32#.openolt.OnuSignalDegradeIndicationH\x00\x12\x46\n\x17onu_drift_of_window_ind\x18\x06 \x01(\x0b\x32#.openolt.OnuDriftOfWindowIndicationH\x00\x12\x44\n\x11onu_loss_omci_ind\x18\x07 \x01(\x0b\x32\'.openolt.OnuLossOfOmciChannelIndicationH\x00\x12\x44\n\x14onu_signals_fail_ind\x18\x08 \x01(\x0b\x32$.openolt.OnuSignalsFailureIndicationH\x00\x12\x43\n\x0conu_tiwi_ind\x18\t \x01(\x0b\x32+.openolt.OnuTransmissionInterferenceWarningH\x00\x12J\n\x17onu_activation_fail_ind\x18\n \x01(\x0b\x32\'.openolt.OnuActivationFailureIndicationH\x00\x12I\n\x18onu_processing_error_ind\x18\x0b \x01(\x0b\x32%.openolt.OnuProcessingErrorIndicationH\x00\x12O\n\x19onu_loss_of_sync_fail_ind\x18\x0c \x01(\x0b\x32*.openolt.OnuLossOfKeySyncFailureIndicationH\x00\x12\x42\n\x15onu_itu_pon_stats_ind\x18\r \x01(\x0b\x32!.openolt.OnuItuPonStatsIndicationH\x00\x12Q\n\x1conu_deactivation_failure_ind\x18\x0e \x01(\x0b\x32).openolt.OnuDeactivationFailureIndicationH\x00\x12\x43\n\x15onu_remote_defect_ind\x18\x0f \x01(\x0b\x32\".openolt.OnuRemoteDefectIndicationH\x00\x12Y\n\x1conu_loss_gem_delineation_ind\x18\x10 \x01(\x0b\x32\x31.openolt.OnuLossOfGEMChannelDelineationIndicationH\x00\x12X\n onu_physical_equipment_error_ind\x18\x11 \x01(\x0b\x32,.openolt.OnuPhysicalEquipmentErrorIndicationH\x00\x12J\n\x13onu_loss_of_ack_ind\x18\x12 \x01(\x0b\x32+.openolt.OnuLossOfAcknowledgementIndicationH\x00\x12V\n\x1bonu_diff_reach_exceeded_ind\x18\x13 \x01(\x0b\x32/.openolt.OnuDifferentialReachExceededIndicationH\x00\x42\x06\n\x04\x64\x61ta\"#\n\rOltIndication\x12\x12\n\noper_state\x18\x01 \x01(\t\"5\n\x0eIntfIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\noper_state\x18\x02 \x01(\t\"R\n\x11OnuDiscIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12,\n\rserial_number\x18\x02 \x01(\x0b\x32\x15.openolt.SerialNumber\"\xd3\x03\n\rOnuIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\x12\x13\n\x0b\x61\x64min_state\x18\x05 \x01(\t\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\x12@\n\x0b\x66\x61il_reason\x18\x06 \x01(\x0e\x32+.openolt.OnuIndication.ActivationFailReason\"\x87\x02\n\x14\x41\x63tivationFailReason\x12#\n\x1fONU_ACTIVATION_FAIL_REASON_NONE\x10\x00\x12&\n\"ONU_ACTIVATION_FAIL_REASON_RANGING\x10\x01\x12\x36\n2ONU_ACTIVATION_FAIL_REASON_PASSWORD_AUTHENTICATION\x10\x02\x12\"\n\x1eONU_ACTIVATION_FAIL_REASON_LOS\x10\x03\x12!\n\x1dONU_ACTIVATION_FAIL_ONU_ALARM\x10\x04\x12#\n\x1fONU_ACTIVATION_FAIL_SWITCH_OVER\x10\x05\"f\n\x15OnuDisabledIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\"e\n\x14OnuEnabledIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x04 \x01(\x0b\x32\x15.openolt.SerialNumber\"\xb5\x03\n\x12IntfOperIndication\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07intf_id\x18\x02 \x01(\x07\x12\x12\n\noper_state\x18\x03 \x01(\t\x12\r\n\x05speed\x18\x04 \x01(\x07\x12\x12\n\ntechnology\x18\x05 \x01(\t\x12=\n\x06ranges\x18\x06 \x01(\x0b\x32-.openolt.IntfOperIndication.PONResourceRanges\x1a\x89\x02\n\x11PONResourceRanges\x12\x41\n\x05pools\x18\x03 \x03(\x0b\x32\x32.openolt.IntfOperIndication.PONResourceRanges.Pool\x1a\xb0\x01\n\x04Pool\x12I\n\x04type\x18\x01 \x01(\x0e\x32;.openolt.IntfOperIndication.PONResourceRanges.Pool.PoolType\x12\r\n\x05start\x18\x03 \x01(\x07\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x07\"A\n\x08PoolType\x12\n\n\x06ONU_ID\x10\x00\x12\x0c\n\x08\x41LLOC_ID\x10\x01\x12\x0e\n\nGEMPORT_ID\x10\x02\x12\x0b\n\x07\x46LOW_ID\x10\x03\">\n\x0eOmciIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"\xa9\x01\n\x10PacketIndication\x12\x11\n\tintf_type\x18\x05 \x01(\t\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x08 \x01(\x07\x12\x0e\n\x06uni_id\x18\t \x01(\x07\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x07\x12\x0f\n\x07port_no\x18\x06 \x01(\x07\x12\x0e\n\x06\x63ookie\x18\x07 \x01(\x06\x12\x0b\n\x03pkt\x18\x04 \x01(\x0c\"/\n\tInterface\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x11\n\tintf_type\x18\x02 \x01(\x07\"(\n\tHeartbeat\x12\x1b\n\x13heartbeat_signature\x18\x01 \x01(\x07\"z\n\x03Onu\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12,\n\rserial_number\x18\x03 \x01(\x0b\x32\x15.openolt.SerialNumber\x12\x0b\n\x03pir\x18\x04 \x01(\x07\x12\x17\n\x0fomcc_encryption\x18\x05 \x01(\x08\"v\n\x12OnuLogicalDistance\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12!\n\x19logical_onu_distance_zero\x18\x03 \x01(\x07\x12\x1c\n\x14logical_onu_distance\x18\x04 \x01(\x07\"7\n\x07OmciMsg\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\"p\n\tOnuPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0f\n\x07port_no\x18\x04 \x01(\x07\x12\x12\n\ngemport_id\x18\x05 \x01(\x07\x12\x10\n\x08\x61lloc_id\x18\x06 \x01(\x07\x12\x0b\n\x03pkt\x18\x03 \x01(\x0c\",\n\x0cUplinkPacket\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0b\n\x03pkt\x18\x02 \x01(\x0c\"\x81\x06\n\nDeviceInfo\x12\x0e\n\x06vendor\x18\x01 \x01(\t\x12\r\n\x05model\x18\x02 \x01(\t\x12\x18\n\x10hardware_version\x18\x03 \x01(\t\x12\x18\n\x10\x66irmware_version\x18\x04 \x01(\t\x12\x11\n\tdevice_id\x18\x10 \x01(\t\x12\x1c\n\x14\x64\x65vice_serial_number\x18\x11 \x01(\t\x12\x1c\n\x14previously_connected\x18\x13 \x01(\x08\x12\x11\n\tpon_ports\x18\x0c \x01(\x07\x12\x11\n\tnni_ports\x18\x14 \x01(\x07\x12\x38\n\x06ranges\x18\x0f \x03(\x0b\x32(.openolt.DeviceInfo.DeviceResourceRanges\x1a\xde\x03\n\x14\x44\x65viceResourceRanges\x12\x10\n\x08intf_ids\x18\x01 \x03(\x07\x12\x12\n\ntechnology\x18\x02 \x01(\t\x12<\n\x05pools\x18\x03 \x03(\x0b\x32-.openolt.DeviceInfo.DeviceResourceRanges.Pool\x1a\xe1\x02\n\x04Pool\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x36.openolt.DeviceInfo.DeviceResourceRanges.Pool.PoolType\x12J\n\x07sharing\x18\x02 \x01(\x0e\x32\x39.openolt.DeviceInfo.DeviceResourceRanges.Pool.SharingType\x12\r\n\x05start\x18\x03 \x01(\x07\x12\x0b\n\x03\x65nd\x18\x04 \x01(\x07\"A\n\x08PoolType\x12\n\n\x06ONU_ID\x10\x00\x12\x0c\n\x08\x41LLOC_ID\x10\x01\x12\x0e\n\nGEMPORT_ID\x10\x02\x12\x0b\n\x07\x46LOW_ID\x10\x03\"h\n\x0bSharingType\x12\x16\n\x12\x44\x45\x44ICATED_PER_INTF\x10\x00\x12\x1f\n\x1bSHARED_BY_ALL_INTF_ALL_TECH\x10\x01\x12 \n\x1cSHARED_BY_ALL_INTF_SAME_TECH\x10\x02J\x04\x08\x05\x10\x0cJ\x04\x08\r\x10\x0eJ\x04\x08\x0e\x10\x0f\"\x8c\x02\n\nClassifier\x12\x0e\n\x06o_tpid\x18\x01 \x01(\x07\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x03 \x01(\x07\x12\r\n\x05i_vid\x18\x04 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x10\n\x08\x65th_type\x18\x07 \x01(\x07\x12\x0f\n\x07\x64st_mac\x18\x08 \x01(\x0c\x12\x0f\n\x07src_mac\x18\t \x01(\x0c\x12\x10\n\x08ip_proto\x18\n \x01(\x07\x12\x0e\n\x06\x64st_ip\x18\x0b \x01(\x07\x12\x0e\n\x06src_ip\x18\x0c \x01(\x07\x12\x10\n\x08src_port\x18\r \x01(\x07\x12\x10\n\x08\x64st_port\x18\x0e \x01(\x07\x12\x14\n\x0cpkt_tag_type\x18\x0f \x01(\t\"\xf5\x01\n\tActionCmd\x12\x15\n\radd_outer_tag\x18\x01 \x01(\x08\x12\x18\n\x10remove_outer_tag\x18\x02 \x01(\x08\x12\x14\n\x0ctrap_to_host\x18\x03 \x01(\x08\x12\x1a\n\x12remark_outer_pbits\x18\x04 \x01(\x08\x12\x1a\n\x12remark_inner_pbits\x18\x05 \x01(\x08\x12\x15\n\radd_inner_tag\x18\x06 \x01(\x08\x12\x18\n\x10remove_inner_tag\x18\x07 \x01(\x08\x12\x1b\n\x13translate_inner_tag\x18\x08 \x01(\x08\x12\x1b\n\x13translate_outer_tag\x18\t \x01(\x08\"\x89\x01\n\x06\x41\x63tion\x12\x1f\n\x03\x63md\x18\x01 \x01(\x0b\x32\x12.openolt.ActionCmd\x12\r\n\x05o_vid\x18\x02 \x01(\x07\x12\x0f\n\x07o_pbits\x18\x03 \x01(\x07\x12\x0e\n\x06o_tpid\x18\x04 \x01(\x07\x12\r\n\x05i_vid\x18\x05 \x01(\x07\x12\x0f\n\x07i_pbits\x18\x06 \x01(\x07\x12\x0e\n\x06i_tpid\x18\x07 \x01(\x07\"\xdb\x04\n\x04\x46low\x12\x16\n\x0e\x61\x63\x63\x65ss_intf_id\x18\x01 \x01(\x0f\x12\x0e\n\x06onu_id\x18\x02 \x01(\x0f\x12\x0e\n\x06uni_id\x18\x0b \x01(\x0f\x12\x0f\n\x07\x66low_id\x18\x03 \x01(\x06\x12\x19\n\x11symmetric_flow_id\x18\x12 \x01(\x06\x12\x11\n\tflow_type\x18\x04 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\n \x01(\x0f\x12\x17\n\x0fnetwork_intf_id\x18\x05 \x01(\x0f\x12\x12\n\ngemport_id\x18\x06 \x01(\x0f\x12\'\n\nclassifier\x18\x07 \x01(\x0b\x32\x13.openolt.Classifier\x12\x1f\n\x06\x61\x63tion\x18\x08 \x01(\x0b\x32\x0f.openolt.Action\x12\x10\n\x08priority\x18\t \x01(\x0f\x12\x0e\n\x06\x63ookie\x18\x0c \x01(\x06\x12\x0f\n\x07port_no\x18\r \x01(\x07\x12\x10\n\x08group_id\x18\x0e \x01(\x07\x12\x17\n\x0ftech_profile_id\x18\x0f \x01(\x07\x12\x16\n\x0ereplicate_flow\x18\x10 \x01(\x08\x12\x39\n\x0fpbit_to_gemport\x18\x11 \x03(\x0b\x32 .openolt.Flow.PbitToGemportEntry\x12\x37\n\x0egemport_to_aes\x18\x13 \x03(\x0b\x32\x1f.openolt.Flow.GemportToAesEntry\x1a\x34\n\x12PbitToGemportEntry\x12\x0b\n\x03key\x18\x01 \x01(\x07\x12\r\n\x05value\x18\x02 \x01(\x07:\x02\x38\x01\x1a\x33\n\x11GemportToAesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x07\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\":\n\x0cSerialNumber\x12\x11\n\tvendor_id\x18\x01 \x01(\x0c\x12\x17\n\x0fvendor_specific\x18\x02 \x01(\x0c\"\xf5\x04\n\rOnuStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x16\n\x0epositive_drift\x18\x03 \x01(\x06\x12\x16\n\x0enegative_drift\x18\x04 \x01(\x06\x12 \n\x18\x64\x65limiter_miss_detection\x18\x05 \x01(\x06\x12\x12\n\nbip_errors\x18\x06 \x01(\x06\x12\x11\n\tbip_units\x18\x07 \x01(\x06\x12\x1d\n\x15\x66\x65\x63_corrected_symbols\x18\x08 \x01(\x06\x12\x1f\n\x17\x66\x65\x63_codewords_corrected\x18\t \x01(\x06\x12#\n\x1b\x66\x65\x63_codewords_uncorrectable\x18\n \x01(\x06\x12\x15\n\rfec_codewords\x18\x0b \x01(\x06\x12\x1b\n\x13\x66\x65\x63_corrected_units\x18\x0c \x01(\x06\x12\x17\n\x0fxgem_key_errors\x18\r \x01(\x06\x12\x11\n\txgem_loss\x18\x0e \x01(\x06\x12\x17\n\x0frx_ploams_error\x18\x0f \x01(\x06\x12\x1a\n\x12rx_ploams_non_idle\x18\x10 \x01(\x06\x12\x0f\n\x07rx_omci\x18\x11 \x01(\x06\x12!\n\x19rx_omci_packets_crc_error\x18\x12 \x01(\x06\x12\x10\n\x08rx_bytes\x18\x13 \x01(\x06\x12\x12\n\nrx_packets\x18\x14 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x15 \x01(\x06\x12\x12\n\ntx_packets\x18\x16 \x01(\x06\x12\x14\n\x0c\x62\x65r_reported\x18\x17 \x01(\x06\x12\x13\n\x0blcdg_errors\x18\x18 \x01(\x06\x12\x12\n\nrdi_errors\x18\x19 \x01(\x06\x12\x11\n\ttimestamp\x18\x1a \x01(\x07\"\x97\x01\n\x11GemPortStatistics\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x12\n\ngemport_id\x18\x02 \x01(\x07\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x10\n\x08rx_bytes\x18\x04 \x01(\x06\x12\x12\n\ntx_packets\x18\x05 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x06 \x01(\x06\x12\x11\n\ttimestamp\x18\x1a \x01(\x07\"\x80\x01\n\x0e\x46lowStatistics\x12\x0f\n\x07\x66low_id\x18\x01 \x01(\x07\x12\x10\n\x08rx_bytes\x18\x02 \x01(\x06\x12\x12\n\nrx_packets\x18\x03 \x01(\x06\x12\x10\n\x08tx_bytes\x18\x08 \x01(\x06\x12\x12\n\ntx_packets\x18\t \x01(\x06\x12\x11\n\ttimestamp\x18\x10 \x01(\x07\"0\n\rLosIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06status\x18\x02 \x01(\t\"F\n\x13\x44yingGaspIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xc1\x01\n\x12OnuAlarmIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\nlos_status\x18\x03 \x01(\t\x12\x12\n\nlob_status\x18\x04 \x01(\t\x12\x18\n\x10lopc_miss_status\x18\x05 \x01(\t\x12\x1d\n\x15lopc_mic_error_status\x18\x06 \x01(\t\x12\x13\n\x0blofi_status\x18\x07 \x01(\t\x12\x14\n\x0cloami_status\x18\x08 \x01(\t\"N\n\x1bOnuStartupFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"m\n\x1aOnuSignalDegradeIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"m\n\x1aOnuDriftOfWindowIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\x12\x0f\n\x07new_eqd\x18\x05 \x01(\x07\"Q\n\x1eOnuLossOfOmciChannelIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"n\n\x1bOnuSignalsFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1e\n\x16inverse_bit_error_rate\x18\x04 \x01(\x07\"d\n\"OnuTransmissionInterferenceWarning\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\r\n\x05\x64rift\x18\x04 \x01(\x07\"V\n\x1eOnuActivationFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x13\n\x0b\x66\x61il_reason\x18\x03 \x01(\x07\"T\n!OnuLossOfKeySyncFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"=\n\x12RdiErrorIndication\x12\x17\n\x0frdi_error_count\x18\x01 \x01(\x06\x12\x0e\n\x06status\x18\x02 \x01(\t\"z\n\x18OnuItuPonStatsIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x34\n\rrdi_error_ind\x18\x03 \x01(\x0b\x32\x1b.openolt.RdiErrorIndicationH\x00\x42\x07\n\x05stats\"?\n\x1cOnuProcessingErrorIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"S\n OnuDeactivationFailureIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"P\n\x19OnuRemoteDefectIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x12\n\nrdi_errors\x18\x03 \x01(\x06\"w\n(OnuLossOfGEMChannelDelineationIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65lineation_errors\x18\x04 \x01(\x07\"V\n#OnuPhysicalEquipmentErrorIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"U\n\"OnuLossOfAcknowledgementIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\"k\n&OnuDifferentialReachExceededIndication\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x10\n\x08\x64istance\x18\x04 \x01(\x07\"\xc5\x01\n\x0bGroupMember\x12\x14\n\x0cinterface_id\x18\x01 \x01(\r\x12:\n\x0einterface_type\x18\x02 \x01(\x0e\x32\".openolt.GroupMember.InterfaceType\x12\x13\n\x0bgem_port_id\x18\x03 \x01(\r\x12\x10\n\x08priority\x18\x04 \x01(\r\"=\n\rInterfaceType\x12\x07\n\x03PON\x10\x00\x12\x10\n\x0c\x45PON_1G_PATH\x10\x01\x12\x11\n\rEPON_10G_PATH\x10\x02\"\xe3\x01\n\x05Group\x12\x10\n\x08group_id\x18\x01 \x01(\r\x12\x33\n\x07\x63ommand\x18\x02 \x01(\x0e\x32\".openolt.Group.GroupMembersCommand\x12%\n\x07members\x18\x03 \x03(\x0b\x32\x14.openolt.GroupMember\x12\x1f\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x0f.openolt.Action\"K\n\x13GroupMembersCommand\x12\x0f\n\x0b\x41\x44\x44_MEMBERS\x10\x00\x12\x12\n\x0eREMOVE_MEMBERS\x10\x01\x12\x0f\n\x0bSET_MEMBERS\x10\x02\"Q\n\nValueParam\x12\x19\n\x03onu\x18\x01 \x01(\x0b\x32\x0c.openolt.Onu\x12(\n\x05value\x18\x02 \x01(\x0e\x32\x19.extension.ValueType.Type\"\x90\x02\n\x0ePonRxPowerData\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\x12\x0e\n\x06status\x18\x03 \x01(\t\x12\x46\n\x0b\x66\x61il_reason\x18\x04 \x01(\x0e\x32\x31.openolt.PonRxPowerData.RssiMeasurementFailReason\x12\x19\n\x11rx_power_mean_dbm\x18\x05 \x01(\x01\"j\n\x19RssiMeasurementFailReason\x12\x14\n\x10\x46\x41IL_REASON_NONE\x10\x00\x12\x1c\n\x18\x46\x41IL_REASON_NO_DELIMITER\x10\x01\x12\x19\n\x15\x46\x41IL_REASON_NO_ACCESS\x10\x02\"H\n\x14OnuAllocIdStatistics\x12\x0e\n\x06intfId\x18\x01 \x01(\x07\x12\x0f\n\x07\x61llocId\x18\x02 \x01(\x07\x12\x0f\n\x07rxBytes\x18\x03 \x01(\x06\"\x82\x02\n\x07OnuInfo\x12\x0e\n\x06onu_id\x18\x01 \x01(\x07\x12(\n\x05state\x18\x02 \x01(\x0e\x32\x19.openolt.OnuInfo.OnuState\x12!\n\x04losi\x18\x03 \x01(\x0e\x32\x13.openolt.AlarmState\x12!\n\x04lofi\x18\x04 \x01(\x0e\x32\x13.openolt.AlarmState\x12\"\n\x05loami\x18\x05 \x01(\x0e\x32\x13.openolt.AlarmState\"S\n\x08OnuState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0eNOT_CONFIGURED\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\"\xd3\x01\n\x0bPonIntfInfo\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x30\n\x05state\x18\x03 \x01(\x0e\x32!.openolt.PonIntfInfo.PonIntfState\x12 \n\x03los\x18\x04 \x01(\x0e\x32\x13.openolt.AlarmState\"_\n\x0cPonIntfState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0e\x41\x43TIVE_WORKING\x10\x01\x12\x12\n\x0e\x41\x43TIVE_STANDBY\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\x12\x0c\n\x08\x44ISABLED\x10\x04\"n\n\x1dInterfaceOnuSerialNumberOnuId\x12=\n\x12intf_id_serial_num\x18\x01 \x01(\x0b\x32!.openolt.InterfaceOnuSerialNumber\x12\x0e\n\x06onu_id\x18\x02 \x01(\x07\"]\n\x18InterfaceOnuSerialNumber\x12\x0f\n\x07intf_id\x18\x01 \x01(\x07\x12\x30\n\x11onu_serial_number\x18\x02 \x01(\x0b\x32\x15.openolt.SerialNumber\"\x07\n\x05\x45mpty*\x1d\n\nAlarmState\x12\x07\n\x03OFF\x10\x00\x12\x06\n\x02ON\x10\x01\x32\xa6\x1b\n\x07Openolt\x12\x44\n\nDisableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/Disable:\x01*\x12\x46\n\x0bReenableOlt\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/Reenable:\x01*\x12\x45\n\x0b\x41\x63tivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/EnableOnu:\x01*\x12H\n\rDeactivateOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/DisableOnu:\x01*\x12\x43\n\tDeleteOnu\x12\x0c.openolt.Onu\x1a\x0e.openolt.Empty\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/DeleteOnu:\x01*\x12I\n\nOmciMsgOut\x12\x10.openolt.OmciMsg\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/OmciMsgOut:\x01*\x12O\n\x0cOnuPacketOut\x12\x12.openolt.OnuPacket\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/OnuPacketOut:\x01*\x12X\n\x0fUplinkPacketOut\x12\x15.openolt.UplinkPacket\x1a\x0e.openolt.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/UplinkPacketOut:\x01*\x12@\n\x07\x46lowAdd\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/FlowAdd:\x01*\x12\x46\n\nFlowRemove\x12\r.openolt.Flow\x1a\x0e.openolt.Empty\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/FlowRemove:\x01*\x12S\n\x0eHeartbeatCheck\x12\x0e.openolt.Empty\x1a\x12.openolt.Heartbeat\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/HeartbeatCheck:\x01*\x12M\n\x0b\x45nablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/EnablePonIf:\x01*\x12O\n\x0c\x44isablePonIf\x12\x12.openolt.Interface\x1a\x0e.openolt.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/v1/DisablePonIf:\x01*\x12R\n\rGetDeviceInfo\x12\x0e.openolt.Empty\x1a\x13.openolt.DeviceInfo\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/GetDeviceInfo:\x01*\x12?\n\x06Reboot\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v1/Reboot:\x01*\x12U\n\x11\x43ollectStatistics\x12\x0e.openolt.Empty\x1a\x0e.openolt.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/CollectStatistics:\x01*\x12Y\n\x10GetOnuStatistics\x12\x0c.openolt.Onu\x1a\x16.openolt.OnuStatistics\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/GetOnuStatistics:\x01*\x12k\n\x14GetGemPortStatistics\x12\x12.openolt.OnuPacket\x1a\x1a.openolt.GemPortStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetGemPortStatistics:\x01*\x12r\n\x17\x43reateTrafficSchedulers\x12\x1f.tech_profile.TrafficSchedulers\x1a\x0e.openolt.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/CreateTrafficSchedulers:\x01*\x12r\n\x17RemoveTrafficSchedulers\x12\x1f.tech_profile.TrafficSchedulers\x1a\x0e.openolt.Empty\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/RemoveTrafficSchedulers:\x01*\x12\x66\n\x13\x43reateTrafficQueues\x12\x1b.tech_profile.TrafficQueues\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/CreateTrafficQueues:\x01*\x12\x66\n\x13RemoveTrafficQueues\x12\x1b.tech_profile.TrafficQueues\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/v1/RemoveTrafficQueues:\x01*\x12;\n\x10\x45nableIndication\x12\x0e.openolt.Empty\x1a\x13.openolt.Indication\"\x00\x30\x01\x12]\n\x15PerformGroupOperation\x12\x0e.openolt.Group\x1a\x0e.openolt.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/PerformGroupOperation:\x01*\x12I\n\x0b\x44\x65leteGroup\x12\x0e.openolt.Group\x1a\x0e.openolt.Empty\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/DeleteGroup:\x01*\x12W\n\x0bGetExtValue\x12\x13.openolt.ValueParam\x1a\x17.extension.ReturnValues\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/GetExtValue:\x01*\x12]\n\x11OnuItuPonAlarmSet\x12\x16.config.OnuItuPonAlarm\x1a\x0e.openolt.Empty\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v1/OnuItuPonAlarmSet:\x01*\x12p\n\x19GetLogicalOnuDistanceZero\x12\x0c.openolt.Onu\x1a\x1b.openolt.OnuLogicalDistance\"(\x82\xd3\xe4\x93\x02\"\"\x1d/v1/GetLogicalOnuDistanceZero:\x01*\x12h\n\x15GetLogicalOnuDistance\x12\x0c.openolt.Onu\x1a\x1b.openolt.OnuLogicalDistance\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/GetLogicalOnuDistance:\x01*\x12T\n\rGetPonRxPower\x12\x0c.openolt.Onu\x1a\x17.openolt.PonRxPowerData\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/GetPonRxPower:\x01*\x12G\n\nGetOnuInfo\x12\x0c.openolt.Onu\x1a\x10.openolt.OnuInfo\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/v1/GetOnuInfo:\x01*\x12`\n\x13GetPonInterfaceInfo\x12\x12.openolt.Interface\x1a\x14.openolt.PonIntfInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v1/GetInterfaceInfo:\x01*\x12n\n\x14GetAllocIdStatistics\x12\x12.openolt.OnuPacket\x1a\x1d.openolt.OnuAllocIdStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetAllocIdStatistics:\x01*\x12g\n\x14GetPonPortStatistics\x12\x12.openolt.Interface\x1a\x16.common.PortStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetPonPortStatistics:\x01*\x12g\n\x14GetNniPortStatistics\x12\x12.openolt.Interface\x1a\x16.common.PortStatistics\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/GetNniPortStatistics:\x01*\x12\\\n\nDisableOnu\x12&.openolt.InterfaceOnuSerialNumberOnuId\x1a\x0e.openolt.Empty\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0e/v1/DisableOnu\x12Z\n\tEnableOnu\x12&.openolt.InterfaceOnuSerialNumberOnuId\x1a\x0e.openolt.Empty\"\x15\x82\xd3\xe4\x93\x02\x0f\"\r/v1/EnableOnu\x12o\n\x16\x44isableOnuSerialNumber\x12!.openolt.InterfaceOnuSerialNumber\x1a\x0e.openolt.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/v1/DisableOnuSerialNumber\x12m\n\x15\x45nableOnuSerialNumber\x12!.openolt.InterfaceOnuSerialNumber\x1a\x0e.openolt.Empty\"!\x82\xd3\xe4\x93\x02\x1b\"\x19/v1/EnableOnuSerialNumberB]\n\x1borg.opencord.voltha.openoltB\rVolthaOpenOLTZ/github.com/opencord/voltha-protos/v5/go/openoltb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.openolt_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033org.opencord.voltha.openoltB\rVolthaOpenOLTZ/github.com/opencord/voltha-protos/v5/go/openolt'
  _globals['_FLOW_PBITTOGEMPORTENTRY']._options = None
  _globals['_FLOW_PBITTOGEMPORTENTRY']._serialized_options = b'8\001'
  _globals['_FLOW_GEMPORTTOAESENTRY']._options = None
  _globals['_FLOW_GEMPORTTOAESENTRY']._serialized_options = b'8\001'
  _globals['_OPENOLT'].methods_by_name['DisableOlt']._options = None
  _globals['_OPENOLT'].methods_by_name['DisableOlt']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/Disable:\001*'
  _globals['_OPENOLT'].methods_by_name['ReenableOlt']._options = None
  _globals['_OPENOLT'].methods_by_name['ReenableOlt']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/Reenable:\001*'
  _globals['_OPENOLT'].methods_by_name['ActivateOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['ActivateOnu']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/EnableOnu:\001*'
  _globals['_OPENOLT'].methods_by_name['DeactivateOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['DeactivateOnu']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/DisableOnu:\001*'
  _globals['_OPENOLT'].methods_by_name['DeleteOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['DeleteOnu']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/DeleteOnu:\001*'
  _globals['_OPENOLT'].methods_by_name['OmciMsgOut']._options = None
  _globals['_OPENOLT'].methods_by_name['OmciMsgOut']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/OmciMsgOut:\001*'
  _globals['_OPENOLT'].methods_by_name['OnuPacketOut']._options = None
  _globals['_OPENOLT'].methods_by_name['OnuPacketOut']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/OnuPacketOut:\001*'
  _globals['_OPENOLT'].methods_by_name['UplinkPacketOut']._options = None
  _globals['_OPENOLT'].methods_by_name['UplinkPacketOut']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/UplinkPacketOut:\001*'
  _globals['_OPENOLT'].methods_by_name['FlowAdd']._options = None
  _globals['_OPENOLT'].methods_by_name['FlowAdd']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/FlowAdd:\001*'
  _globals['_OPENOLT'].methods_by_name['FlowRemove']._options = None
  _globals['_OPENOLT'].methods_by_name['FlowRemove']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/FlowRemove:\001*'
  _globals['_OPENOLT'].methods_by_name['HeartbeatCheck']._options = None
  _globals['_OPENOLT'].methods_by_name['HeartbeatCheck']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/HeartbeatCheck:\001*'
  _globals['_OPENOLT'].methods_by_name['EnablePonIf']._options = None
  _globals['_OPENOLT'].methods_by_name['EnablePonIf']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/EnablePonIf:\001*'
  _globals['_OPENOLT'].methods_by_name['DisablePonIf']._options = None
  _globals['_OPENOLT'].methods_by_name['DisablePonIf']._serialized_options = b'\202\323\344\223\002\025\"\020/v1/DisablePonIf:\001*'
  _globals['_OPENOLT'].methods_by_name['GetDeviceInfo']._options = None
  _globals['_OPENOLT'].methods_by_name['GetDeviceInfo']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/GetDeviceInfo:\001*'
  _globals['_OPENOLT'].methods_by_name['Reboot']._options = None
  _globals['_OPENOLT'].methods_by_name['Reboot']._serialized_options = b'\202\323\344\223\002\017\"\n/v1/Reboot:\001*'
  _globals['_OPENOLT'].methods_by_name['CollectStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['CollectStatistics']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/CollectStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetOnuStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetOnuStatistics']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/GetOnuStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetGemPortStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetGemPortStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetGemPortStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['CreateTrafficSchedulers']._options = None
  _globals['_OPENOLT'].methods_by_name['CreateTrafficSchedulers']._serialized_options = b'\202\323\344\223\002 \"\033/v1/CreateTrafficSchedulers:\001*'
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficSchedulers']._options = None
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficSchedulers']._serialized_options = b'\202\323\344\223\002 \"\033/v1/RemoveTrafficSchedulers:\001*'
  _globals['_OPENOLT'].methods_by_name['CreateTrafficQueues']._options = None
  _globals['_OPENOLT'].methods_by_name['CreateTrafficQueues']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/CreateTrafficQueues:\001*'
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficQueues']._options = None
  _globals['_OPENOLT'].methods_by_name['RemoveTrafficQueues']._serialized_options = b'\202\323\344\223\002\034\"\027/v1/RemoveTrafficQueues:\001*'
  _globals['_OPENOLT'].methods_by_name['PerformGroupOperation']._options = None
  _globals['_OPENOLT'].methods_by_name['PerformGroupOperation']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/PerformGroupOperation:\001*'
  _globals['_OPENOLT'].methods_by_name['DeleteGroup']._options = None
  _globals['_OPENOLT'].methods_by_name['DeleteGroup']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/DeleteGroup:\001*'
  _globals['_OPENOLT'].methods_by_name['GetExtValue']._options = None
  _globals['_OPENOLT'].methods_by_name['GetExtValue']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/GetExtValue:\001*'
  _globals['_OPENOLT'].methods_by_name['OnuItuPonAlarmSet']._options = None
  _globals['_OPENOLT'].methods_by_name['OnuItuPonAlarmSet']._serialized_options = b'\202\323\344\223\002\032\"\025/v1/OnuItuPonAlarmSet:\001*'
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistanceZero']._options = None
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistanceZero']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/GetLogicalOnuDistanceZero:\001*'
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistance']._options = None
  _globals['_OPENOLT'].methods_by_name['GetLogicalOnuDistance']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/GetLogicalOnuDistance:\001*'
  _globals['_OPENOLT'].methods_by_name['GetPonRxPower']._options = None
  _globals['_OPENOLT'].methods_by_name['GetPonRxPower']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/GetPonRxPower:\001*'
  _globals['_OPENOLT'].methods_by_name['GetOnuInfo']._options = None
  _globals['_OPENOLT'].methods_by_name['GetOnuInfo']._serialized_options = b'\202\323\344\223\002\023\"\016/v1/GetOnuInfo:\001*'
  _globals['_OPENOLT'].methods_by_name['GetPonInterfaceInfo']._options = None
  _globals['_OPENOLT'].methods_by_name['GetPonInterfaceInfo']._serialized_options = b'\202\323\344\223\002\031\"\024/v1/GetInterfaceInfo:\001*'
  _globals['_OPENOLT'].methods_by_name['GetAllocIdStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetAllocIdStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetAllocIdStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetPonPortStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetPonPortStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetPonPortStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['GetNniPortStatistics']._options = None
  _globals['_OPENOLT'].methods_by_name['GetNniPortStatistics']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/GetNniPortStatistics:\001*'
  _globals['_OPENOLT'].methods_by_name['DisableOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['DisableOnu']._serialized_options = b'\202\323\344\223\002\020\"\016/v1/DisableOnu'
  _globals['_OPENOLT'].methods_by_name['EnableOnu']._options = None
  _globals['_OPENOLT'].methods_by_name['EnableOnu']._serialized_options = b'\202\323\344\223\002\017\"\r/v1/EnableOnu'
  _globals['_OPENOLT'].methods_by_name['DisableOnuSerialNumber']._options = None
  _globals['_OPENOLT'].methods_by_name['DisableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002\034\"\032/v1/DisableOnuSerialNumber'
  _globals['_OPENOLT'].methods_by_name['EnableOnuSerialNumber']._options = None
  _globals['_OPENOLT'].methods_by_name['EnableOnuSerialNumber']._serialized_options = b'\202\323\344\223\002\033\"\031/v1/EnableOnuSerialNumber'
  _globals['_ALARMSTATE']._serialized_start=10768
  _globals['_ALARMSTATE']._serialized_end=10797
  _globals['_INDICATION']._serialized_start=197
  _globals['_INDICATION']._serialized_end=803
  _globals['_ALARMINDICATION']._serialized_start=806
  _globals['_ALARMINDICATION']._serialized_end=2203
  _globals['_OLTINDICATION']._serialized_start=2205
  _globals['_OLTINDICATION']._serialized_end=2240
  _globals['_INTFINDICATION']._serialized_start=2242
  _globals['_INTFINDICATION']._serialized_end=2295
  _globals['_ONUDISCINDICATION']._serialized_start=2297
  _globals['_ONUDISCINDICATION']._serialized_end=2379
  _globals['_ONUINDICATION']._serialized_start=2382
  _globals['_ONUINDICATION']._serialized_end=2849
  _globals['_ONUINDICATION_ACTIVATIONFAILREASON']._serialized_start=2586
  _globals['_ONUINDICATION_ACTIVATIONFAILREASON']._serialized_end=2849
  _globals['_ONUDISABLEDINDICATION']._serialized_start=2851
  _globals['_ONUDISABLEDINDICATION']._serialized_end=2953
  _globals['_ONUENABLEDINDICATION']._serialized_start=2955
  _globals['_ONUENABLEDINDICATION']._serialized_end=3056
  _globals['_INTFOPERINDICATION']._serialized_start=3059
  _globals['_INTFOPERINDICATION']._serialized_end=3496
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES']._serialized_start=3231
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES']._serialized_end=3496
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL']._serialized_start=3320
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL']._serialized_end=3496
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL_POOLTYPE']._serialized_start=3431
  _globals['_INTFOPERINDICATION_PONRESOURCERANGES_POOL_POOLTYPE']._serialized_end=3496
  _globals['_OMCIINDICATION']._serialized_start=3498
  _globals['_OMCIINDICATION']._serialized_end=3560
  _globals['_PACKETINDICATION']._serialized_start=3563
  _globals['_PACKETINDICATION']._serialized_end=3732
  _globals['_INTERFACE']._serialized_start=3734
  _globals['_INTERFACE']._serialized_end=3781
  _globals['_HEARTBEAT']._serialized_start=3783
  _globals['_HEARTBEAT']._serialized_end=3823
  _globals['_ONU']._serialized_start=3825
  _globals['_ONU']._serialized_end=3947
  _globals['_ONULOGICALDISTANCE']._serialized_start=3949
  _globals['_ONULOGICALDISTANCE']._serialized_end=4067
  _globals['_OMCIMSG']._serialized_start=4069
  _globals['_OMCIMSG']._serialized_end=4124
  _globals['_ONUPACKET']._serialized_start=4126
  _globals['_ONUPACKET']._serialized_end=4238
  _globals['_UPLINKPACKET']._serialized_start=4240
  _globals['_UPLINKPACKET']._serialized_end=4284
  _globals['_DEVICEINFO']._serialized_start=4287
  _globals['_DEVICEINFO']._serialized_end=5056
  _globals['_DEVICEINFO_DEVICERESOURCERANGES']._serialized_start=4560
  _globals['_DEVICEINFO_DEVICERESOURCERANGES']._serialized_end=5038
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL']._serialized_start=4685
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL']._serialized_end=5038
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE']._serialized_start=3431
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_POOLTYPE']._serialized_end=3496
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE']._serialized_start=4934
  _globals['_DEVICEINFO_DEVICERESOURCERANGES_POOL_SHARINGTYPE']._serialized_end=5038
  _globals['_CLASSIFIER']._serialized_start=5059
  _globals['_CLASSIFIER']._serialized_end=5327
  _globals['_ACTIONCMD']._serialized_start=5330
  _globals['_ACTIONCMD']._serialized_end=5575
  _globals['_ACTION']._serialized_start=5578
  _globals['_ACTION']._serialized_end=5715
  _globals['_FLOW']._serialized_start=5718
  _globals['_FLOW']._serialized_end=6321
  _globals['_FLOW_PBITTOGEMPORTENTRY']._serialized_start=6216
  _globals['_FLOW_PBITTOGEMPORTENTRY']._serialized_end=6268
  _globals['_FLOW_GEMPORTTOAESENTRY']._serialized_start=6270
  _globals['_FLOW_GEMPORTTOAESENTRY']._serialized_end=6321
  _globals['_SERIALNUMBER']._serialized_start=6323
  _globals['_SERIALNUMBER']._serialized_end=6381
  _globals['_ONUSTATISTICS']._serialized_start=6384
  _globals['_ONUSTATISTICS']._serialized_end=7013
  _globals['_GEMPORTSTATISTICS']._serialized_start=7016
  _globals['_GEMPORTSTATISTICS']._serialized_end=7167
  _globals['_FLOWSTATISTICS']._serialized_start=7170
  _globals['_FLOWSTATISTICS']._serialized_end=7298
  _globals['_LOSINDICATION']._serialized_start=7300
  _globals['_LOSINDICATION']._serialized_end=7348
  _globals['_DYINGGASPINDICATION']._serialized_start=7350
  _globals['_DYINGGASPINDICATION']._serialized_end=7420
  _globals['_ONUALARMINDICATION']._serialized_start=7423
  _globals['_ONUALARMINDICATION']._serialized_end=7616
  _globals['_ONUSTARTUPFAILUREINDICATION']._serialized_start=7618
  _globals['_ONUSTARTUPFAILUREINDICATION']._serialized_end=7696
  _globals['_ONUSIGNALDEGRADEINDICATION']._serialized_start=7698
  _globals['_ONUSIGNALDEGRADEINDICATION']._serialized_end=7807
  _globals['_ONUDRIFTOFWINDOWINDICATION']._serialized_start=7809
  _globals['_ONUDRIFTOFWINDOWINDICATION']._serialized_end=7918
  _globals['_ONULOSSOFOMCICHANNELINDICATION']._serialized_start=7920
  _globals['_ONULOSSOFOMCICHANNELINDICATION']._serialized_end=8001
  _globals['_ONUSIGNALSFAILUREINDICATION']._serialized_start=8003
  _globals['_ONUSIGNALSFAILUREINDICATION']._serialized_end=8113
  _globals['_ONUTRANSMISSIONINTERFERENCEWARNING']._serialized_start=8115
  _globals['_ONUTRANSMISSIONINTERFERENCEWARNING']._serialized_end=8215
  _globals['_ONUACTIVATIONFAILUREINDICATION']._serialized_start=8217
  _globals['_ONUACTIVATIONFAILUREINDICATION']._serialized_end=8303
  _globals['_ONULOSSOFKEYSYNCFAILUREINDICATION']._serialized_start=8305
  _globals['_ONULOSSOFKEYSYNCFAILUREINDICATION']._serialized_end=8389
  _globals['_RDIERRORINDICATION']._serialized_start=8391
  _globals['_RDIERRORINDICATION']._serialized_end=8452
  _globals['_ONUITUPONSTATSINDICATION']._serialized_start=8454
  _globals['_ONUITUPONSTATSINDICATION']._serialized_end=8576
  _globals['_ONUPROCESSINGERRORINDICATION']._serialized_start=8578
  _globals['_ONUPROCESSINGERRORINDICATION']._serialized_end=8641
  _globals['_ONUDEACTIVATIONFAILUREINDICATION']._serialized_start=8643
  _globals['_ONUDEACTIVATIONFAILUREINDICATION']._serialized_end=8726
  _globals['_ONUREMOTEDEFECTINDICATION']._serialized_start=8728
  _globals['_ONUREMOTEDEFECTINDICATION']._serialized_end=8808
  _globals['_ONULOSSOFGEMCHANNELDELINEATIONINDICATION']._serialized_start=8810
  _globals['_ONULOSSOFGEMCHANNELDELINEATIONINDICATION']._serialized_end=8929
  _globals['_ONUPHYSICALEQUIPMENTERRORINDICATION']._serialized_start=8931
  _globals['_ONUPHYSICALEQUIPMENTERRORINDICATION']._serialized_end=9017
  _globals['_ONULOSSOFACKNOWLEDGEMENTINDICATION']._serialized_start=9019
  _globals['_ONULOSSOFACKNOWLEDGEMENTINDICATION']._serialized_end=9104
  _globals['_ONUDIFFERENTIALREACHEXCEEDEDINDICATION']._serialized_start=9106
  _globals['_ONUDIFFERENTIALREACHEXCEEDEDINDICATION']._serialized_end=9213
  _globals['_GROUPMEMBER']._serialized_start=9216
  _globals['_GROUPMEMBER']._serialized_end=9413
  _globals['_GROUPMEMBER_INTERFACETYPE']._serialized_start=9352
  _globals['_GROUPMEMBER_INTERFACETYPE']._serialized_end=9413
  _globals['_GROUP']._serialized_start=9416
  _globals['_GROUP']._serialized_end=9643
  _globals['_GROUP_GROUPMEMBERSCOMMAND']._serialized_start=9568
  _globals['_GROUP_GROUPMEMBERSCOMMAND']._serialized_end=9643
  _globals['_VALUEPARAM']._serialized_start=9645
  _globals['_VALUEPARAM']._serialized_end=9726
  _globals['_PONRXPOWERDATA']._serialized_start=9729
  _globals['_PONRXPOWERDATA']._serialized_end=10001
  _globals['_PONRXPOWERDATA_RSSIMEASUREMENTFAILREASON']._serialized_start=9895
  _globals['_PONRXPOWERDATA_RSSIMEASUREMENTFAILREASON']._serialized_end=10001
  _globals['_ONUALLOCIDSTATISTICS']._serialized_start=10003
  _globals['_ONUALLOCIDSTATISTICS']._serialized_end=10075
  _globals['_ONUINFO']._serialized_start=10078
  _globals['_ONUINFO']._serialized_end=10336
  _globals['_ONUINFO_ONUSTATE']._serialized_start=10253
  _globals['_ONUINFO_ONUSTATE']._serialized_end=10336
  _globals['_PONINTFINFO']._serialized_start=10339
  _globals['_PONINTFINFO']._serialized_end=10550
  _globals['_PONINTFINFO_PONINTFSTATE']._serialized_start=10455
  _globals['_PONINTFINFO_PONINTFSTATE']._serialized_end=10550
  _globals['_INTERFACEONUSERIALNUMBERONUID']._serialized_start=10552
  _globals['_INTERFACEONUSERIALNUMBERONUID']._serialized_end=10662
  _globals['_INTERFACEONUSERIALNUMBER']._serialized_start=10664
  _globals['_INTERFACEONUSERIALNUMBER']._serialized_end=10757
  _globals['_EMPTY']._serialized_start=10759
  _globals['_EMPTY']._serialized_end=10766
  _globals['_OPENOLT']._serialized_start=10800
  _globals['_OPENOLT']._serialized_end=14294
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core_services.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from voltha_protos import core_adapter_pb2 as voltha__protos_dot_core__adapter__pb2
from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import health_pb2 as voltha__protos_dot_health__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!voltha_protos/core_services.proto\x12\x0c\x63ore_service\x1a\x1bgoogle/protobuf/empty.proto\x1a voltha_protos/core_adapter.proto\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/device.proto\x1a\x1avoltha_protos/health.proto2\xfd\x0b\n\x0b\x43oreService\x12?\n\x0fGetHealthStatus\x12\x12.common.Connection\x1a\x14.health.HealthStatus(\x01\x30\x01\x12L\n\x0fRegisterAdapter\x12!.core_adapter.AdapterRegistration\x1a\x16.google.protobuf.Empty\x12\x36\n\x0c\x44\x65viceUpdate\x12\x0e.device.Device\x1a\x16.google.protobuf.Empty\x12\x33\n\x0bPortCreated\x12\x0c.device.Port\x1a\x16.google.protobuf.Empty\x12I\n\x10PortsStateUpdate\x12\x1d.core_adapter.PortStateFilter\x1a\x16.google.protobuf.Empty\x12\x34\n\x0e\x44\x65leteAllPorts\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\x37\n\rGetDevicePort\x12\x18.core_adapter.PortFilter\x1a\x0c.device.Port\x12,\n\x0fListDevicePorts\x12\n.common.ID\x1a\r.device.Ports\x12L\n\x11\x44\x65viceStateUpdate\x12\x1f.core_adapter.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x41\n\x14\x44\x65vicePMConfigUpdate\x12\x11.device.PmConfigs\x1a\x16.google.protobuf.Empty\x12\x44\n\x13\x43hildDeviceDetected\x12\x1d.core_adapter.DeviceDiscovery\x1a\x0e.device.Device\x12\x36\n\x10\x43hildDevicesLost\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12:\n\x14\x43hildDevicesDetected\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12\'\n\tGetDevice\x12\n.common.ID\x1a\x0e.device.Device\x12\x41\n\x0eGetChildDevice\x12\x1f.core_adapter.ChildDeviceFilter\x1a\x0e.device.Device\x12.\n\x0fGetChildDevices\x12\n.common.ID\x1a\x0f.device.Devices\x12>\n\x0cSendPacketIn\x12\x16.core_adapter.PacketIn\x1a\x16.google.protobuf.Empty\x12H\n\x12\x44\x65viceReasonUpdate\x12\x1a.core_adapter.DeviceReason\x1a\x16.google.protobuf.Empty\x12\x42\n\x0fPortStateUpdate\x12\x17.core_adapter.PortState\x1a\x16.google.protobuf.Empty\x12;\n\x15ReconcileChildDevices\x12\n.common.ID\x1a\x16.google.protobuf.Empty\x12M\n\x1eGetChildDeviceWithProxyAddress\x12\x1b.device.Device.ProxyAddress\x1a\x0e.device.Device\x12\x33\n\x08GetPorts\x12\x18.core_adapter.PortFilter\x1a\r.device.Ports\x12N\n\x13\x43hildrenStateUpdate\x12\x1f.core_adapter.DeviceStateFilter\x1a\x16.google.protobuf.Empty\x12\x44\n\x13UpdateImageDownload\x12\x15.device.ImageDownload\x1a\x16.google.protobuf.EmptyBk\n org.opencord.voltha.core_serviceB\x11VolthaCoreServiceZ4github.com/opencord/voltha-protos/v5/go/core_serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.core_services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n org.opencord.voltha.core_serviceB\021VolthaCoreServiceZ4github.com/opencord/voltha-protos/v5/go/core_service'
  _globals['_CORESERVICE']._serialized_start=199
  _globals['_CORESERVICE']._serialized_end=1732
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core_adapter.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import openflow_13_pb2 as voltha__protos_dot_openflow__13__pb2
from voltha_protos import adapter_pb2 as voltha__protos_dot_adapter__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2
from voltha_protos import extensions_pb2 as voltha__protos_dot_extensions__pb2
from voltha_protos import omci_test_pb2 as voltha__protos_dot_omci__test__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n voltha_protos/core_adapter.proto\x12\x0c\x63ore_adapter\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/voltha.proto\x1a\x1fvoltha_protos/openflow_13.proto\x1a\x1bvoltha_protos/adapter.proto\x1a\x1avoltha_protos/device.proto\x1a\x1evoltha_protos/extensions.proto\x1a\x1dvoltha_protos/omci_test.proto\"]\n\x13\x41\x64\x61pterRegistration\x12!\n\x07\x61\x64\x61pter\x18\x01 \x01(\x0b\x32\x10.adapter.Adapter\x12#\n\x06\x64Types\x18\x02 \x01(\x0b\x32\x13.device.DeviceTypes\"u\n\x11\x43hildDeviceFilter\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x15\n\rserial_number\x18\x02 \x01(\t\x12\x13\n\x06onu_id\x18\x03 \x01(\rH\x00\x88\x01\x01\x12\x16\n\x0eparent_port_no\x18\x04 \x01(\rB\t\n\x07_onu_id\"W\n\nPortFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12(\n\tport_type\x18\x03 \x01(\x0e\x32\x15.device.Port.PortType\"\xa5\x01\n\x0f\x44\x65viceDiscovery\x12\x11\n\tparent_id\x18\x01 \x01(\t\x12\x16\n\x0eparent_port_no\x18\x02 \x01(\r\x12\x19\n\x11\x63hild_device_type\x18\x03 \x01(\t\x12\x12\n\nchannel_id\x18\x04 \x01(\r\x12\x11\n\tvendor_id\x18\x05 \x01(\t\x12\x15\n\rserial_number\x18\x06 \x01(\t\x12\x0e\n\x06onu_id\x18\x07 \x01(\r\"\xa1\x01\n\x11\x44\x65viceStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10parent_device_id\x18\x02 \x01(\t\x12-\n\x0boper_status\x18\x03 \x01(\x0e\x32\x18.common.OperStatus.Types\x12\x30\n\x0b\x63onn_status\x18\x04 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\"\x88\x01\n\tPortState\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12(\n\tport_type\x18\x02 \x01(\x0e\x32\x15.device.Port.PortType\x12\x0f\n\x07port_no\x18\x03 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\"m\n\x0fPortStateFilter\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10port_type_filter\x18\x02 \x01(\r\x12-\n\x0boper_status\x18\x04 \x01(\x0e\x32\x18.common.OperStatus.Types\";\n\x08PacketIn\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\r\x12\x0e\n\x06packet\x18\x03 \x01(\x0c\"c\n\tPacketOut\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x16\n\x0e\x65gress_port_no\x18\x02 \x01(\r\x12+\n\x06packet\x18\x03 \x01(\x0b\x32\x1b.openflow_13.ofp_packet_out\"1\n\x0c\x44\x65viceReason\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\xa9\x01\n\tBulkFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12!\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x12.openflow_13.Flows\x12\'\n\x06groups\x18\x03 \x01(\x0b\x32\x17.openflow_13.FlowGroups\x12\x30\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x19.openflow_13.FlowMetadata\"\xbc\x01\n\x10IncrementalFlows\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12\'\n\x05\x66lows\x18\x02 \x01(\x0b\x32\x18.openflow_13.FlowChanges\x12-\n\x06groups\x18\x03 \x01(\x0b\x32\x1d.openflow_13.FlowGroupChanges\x12\x30\n\rflow_metadata\x18\x04 \x01(\x0b\x32\x19.openflow_13.FlowMetadata\"I\n\rPmConfigsInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12%\n\npm_configs\x18\x02 \x01(\x0b\x32\x11.device.PmConfigs\"r\n\x10SwitchCapability\x12#\n\x04\x64\x65sc\x18\x01 \x01(\x0b\x32\x15.openflow_13.ofp_desc\x12\x39\n\x0fswitch_features\x18\x02 \x01(\x0b\x32 .openflow_13.ofp_switch_features\"\\\n\x14ImageDownloadMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12$\n\x05image\x18\x02 \x01(\x0b\x32\x15.device.ImageDownload\"R\n\x08OMCITest\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12&\n\x07request\x18\x02 \x01(\x0b\x32\x15.omci.OmciTestRequest\"e\n\x14SimulateAlarmMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12-\n\x07request\x18\x02 \x01(\x0b\x32\x1c.device.SimulateAlarmRequest\"\x90\x01\n\x12GetExtValueMessage\x12%\n\rparent_device\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12$\n\x0c\x63hild_device\x18\x02 \x01(\x0b\x32\x0e.device.Device\x12-\n\nvalue_type\x18\x03 \x01(\x0e\x32\x19.extension.ValueType.Type\"X\n\x12SetExtValueMessage\x12\x1e\n\x06\x64\x65vice\x18\x01 \x01(\x0b\x32\x0e.device.Device\x12\"\n\x05value\x18\x03 \x01(\x0b\x32\x13.extension.ValueSetBX\n org.opencord.voltha.core_adapterZ4github.com/opencord/voltha-protos/v5/go/core_adapterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.core_adapter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n org.opencord.voltha.core_adapterZ4github.com/opencord/voltha-protos/v5/go/core_adapter'
  _globals['_ADAPTERREGISTRATION']._serialized_start=259
  _globals['_ADAPTERREGISTRATION']._serialized_end=352
  _globals['_CHILDDEVICEFILTER']._serialized_start=354
  _globals['_CHILDDEVICEFILTER']._serialized_end=471
  _globals['_PORTFILTER']._serialized_start=473
  _globals['_PORTFILTER']._serialized_end=560
  _globals['_DEVICEDISCOVERY']._serialized_start=563
  _globals['_DEVICEDISCOVERY']._serialized_end=728
  _globals['_DEVICESTATEFILTER']._serialized_start=731
  _globals['_DEVICESTATEFILTER']._serialized_end=892
  _globals['_PORTSTATE']._serialized_start=895
  _globals['_PORTSTATE']._serialized_end=1031
  _globals['_PORTSTATEFILTER']._serialized_start=1033
  _globals['_PORTSTATEFILTER']._serialized_end=1142
  _globals['_PACKETIN']._serialized_start=1144
  _globals['_PACKETIN']._serialized_end=1203
  _globals['_PACKETOUT']._serialized_start=1205
  _globals['_PACKETOUT']._serialized_end=1304
  _globals['_DEVICEREASON']._serialized_start=1306
  _globals['_DEVICEREASON']._serialized_end=1355
  _globals['_BULKFLOWS']._serialized_start=1358
  _globals['_BULKFLOWS']._serialized_end=1527
  _globals['_INCREMENTALFLOWS']._serialized_start=1530
  _globals['_INCREMENTALFLOWS']._serialized_end=1718
  _globals['_PMCONFIGSINFO']._serialized_start=1720
  _globals['_PMCONFIGSINFO']._serialized_end=1793
  _globals['_SWITCHCAPABILITY']._serialized_start=1795
  _globals['_SWITCHCAPABILITY']._serialized_end=1909
  _globals['_IMAGEDOWNLOADMESSAGE']._serialized_start=1911
  _globals['_IMAGEDOWNLOADMESSAGE']._serialized_end=2003
  _globals['_OMCITEST']._serialized_start=2005
  _globals['_OMCITEST']._serialized_end=2087
  _globals['_SIMULATEALARMMESSAGE']._serialized_start=2089
  _globals['_SIMULATEALARMMESSAGE']._serialized_end=2190
  _globals['_GETEXTVALUEMESSAGE']._serialized_start=2193
  _globals['_GETEXTVALUEMESSAGE']._serialized_end=2337
  _globals['_SETEXTVALUEMESSAGE']._serialized_start=2339
  _globals['_SETEXTVALUEMESSAGE']._serialized_end=2427
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/omci_alarm_db.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!voltha_protos/omci_alarm_db.proto\x12\x04omci\"1\n\x12\x41larmAttributeData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"y\n\x11\x41larmInstanceData\x12\x13\n\x0binstance_id\x18\x01 \x01(\r\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x10\n\x08modified\x18\x03 \x01(\t\x12,\n\nattributes\x18\x04 \x03(\x0b\x32\x18.omci.AlarmAttributeData\"N\n\x0e\x41larmClassData\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12*\n\tinstances\x18\x02 \x03(\x0b\x32\x17.omci.AlarmInstanceData\"4\n\x12\x41larmManagedEntity\x12\x10\n\x08\x63lass_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"(\n\x10\x41larmMessageType\x12\x14\n\x0cmessage_type\x18\x01 \x01(\r\"\x85\x02\n\x0f\x41larmDeviceData\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\t\x12\x1b\n\x13last_alarm_sequence\x18\x03 \x01(\r\x12\x16\n\x0elast_sync_time\x18\x04 \x01(\t\x12\x0f\n\x07version\x18\x05 \x01(\r\x12%\n\x07\x63lasses\x18\x06 \x03(\x0b\x32\x14.omci.AlarmClassData\x12\x32\n\x10managed_entities\x18\x07 \x03(\x0b\x32\x18.omci.AlarmManagedEntity\x12-\n\rmessage_types\x18\x08 \x03(\x0b\x32\x16.omci.AlarmMessageType\"?\n\x16\x41larmOpenOmciEventType\"%\n\x11OpenOmciEventType\x12\x10\n\x0cstate_change\x10\x00\"`\n\x12\x41larmOpenOmciEvent\x12<\n\x04type\x18\x01 \x01(\x0e\x32..omci.AlarmOpenOmciEventType.OpenOmciEventType\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\tBH\n\x18org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omcib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.omci_alarm_db_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.omciZ,github.com/opencord/voltha-protos/v5/go/omci'
  _globals['_ALARMATTRIBUTEDATA']._serialized_start=43
  _globals['_ALARMATTRIBUTEDATA']._serialized_end=92
  _globals['_ALARMINSTANCEDATA']._serialized_start=94
  _globals['_ALARMINSTANCEDATA']._serialized_end=215
  _globals['_ALARMCLASSDATA']._serialized_start=217
  _globals['_ALARMCLASSDATA']._serialized_end=295
  _globals['_ALARMMANAGEDENTITY']._serialized_start=297
  _globals['_ALARMMANAGEDENTITY']._serialized_end=349
  _globals['_ALARMMESSAGETYPE']._serialized_start=351
  _globals['_ALARMMESSAGETYPE']._serialized_end=391
  _globals['_ALARMDEVICEDATA']._serialized_start=394
  _globals['_ALARMDEVICEDATA']._serialized_end=655
  _globals['_ALARMOPENOMCIEVENTTYPE']._serialized_start=657
  _globals['_ALARMOPENOMCIEVENTTYPE']._serialized_end=720
  _globals['_ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE']._serialized_start=683
  _globals['_ALARMOPENOMCIEVENTTYPE_OPENOMCIEVENTTYPE']._serialized_end=720
  _globals['_ALARMOPENOMCIEVENT']._serialized_start=722
  _globals['_ALARMOPENOMCIEVENT']._serialized_end=818
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/inter_adapter.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from voltha_protos import common_pb2 as voltha__protos_dot_common__pb2
from voltha_protos import voltha_pb2 as voltha__protos_dot_voltha__pb2
try:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha__protos_dot_common__pb2
except AttributeError:
  voltha__protos_dot_common__pb2 = voltha__protos_dot_voltha__pb2.voltha_protos.common_pb2
from voltha_protos import tech_profile_pb2 as voltha__protos_dot_tech__profile__pb2
from voltha_protos import openolt_pb2 as voltha__protos_dot_openolt__pb2
from voltha_protos import device_pb2 as voltha__protos_dot_device__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!voltha_protos/inter_adapter.proto\x12\rinter_adapter\x1a\x1avoltha_protos/common.proto\x1a\x1avoltha_protos/voltha.proto\x1a voltha_protos/tech_profile.proto\x1a\x1bvoltha_protos/openolt.proto\x1a\x1avoltha_protos/device.proto\"\xba\x01\n\x0bOmciMessage\x12\x0f\n\x07message\x18\x01 \x01(\x0c\x12\x33\n\x0e\x63onnect_status\x18\x02 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12\x32\n\rproxy_address\x18\x03 \x01(\x0b\x32\x1b.device.Device.ProxyAddress\x12\x18\n\x10parent_device_id\x18\x04 \x01(\t\x12\x17\n\x0f\x63hild_device_id\x18\x05 \x01(\t\"\xbc\x01\n\x0cOmciMessages\x12\x10\n\x08messages\x18\x01 \x03(\x0c\x12\x33\n\x0e\x63onnect_status\x18\x02 \x01(\x0e\x32\x1b.common.ConnectStatus.Types\x12\x32\n\rproxy_address\x18\x03 \x01(\x0b\x32\x1b.device.Device.ProxyAddress\x12\x18\n\x10parent_device_id\x18\x04 \x01(\t\x12\x17\n\x0f\x63hild_device_id\x18\x05 \x01(\t\"\xea\x01\n\x1aTechProfileDownloadMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x38\n\x0btp_instance\x18\x04 \x01(\x0b\x32!.tech_profile.TechProfileInstanceH\x00\x12\x41\n\x10\x65pon_tp_instance\x18\x05 \x01(\x0b\x32%.tech_profile.EponTechProfileInstanceH\x00\x42\x12\n\x10tech_tp_instance\"h\n\x14\x44\x65leteGemPortMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x13\n\x0bgem_port_id\x18\x04 \x01(\r\"c\n\x12\x44\x65leteTcontMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x0e\n\x06uni_id\x18\x02 \x01(\r\x12\x18\n\x10tp_instance_path\x18\x03 \x01(\t\x12\x10\n\x08\x61lloc_id\x18\x04 \x01(\r\"Y\n\x14OnuIndicationMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12.\n\x0eonu_indication\x18\x02 \x01(\x0b\x32\x16.openolt.OnuIndication\"\xa3\x01\n!TechProfileInstanceRequestMessage\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12\x18\n\x10tp_instance_path\x18\x02 \x01(\t\x12\x18\n\x10parent_device_id\x18\x03 \x01(\t\x12\x17\n\x0fparent_pon_port\x18\x04 \x01(\r\x12\x0e\n\x06onu_id\x18\x05 \x01(\r\x12\x0e\n\x06uni_id\x18\x06 \x01(\rBZ\n!org.opencord.voltha.inter_adapterZ5github.com/opencord/voltha-protos/v5/go/inter_adapterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.inter_adapter_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!org.opencord.voltha.inter_adapterZ5github.com/opencord/voltha-protos/v5/go/inter_adapter'
  _globals['_OMCIMESSAGE']._serialized_start=200
  _globals['_OMCIMESSAGE']._serialized_end=386
  _globals['_OMCIMESSAGES']._serialized_start=389
  _globals['_OMCIMESSAGES']._serialized_end=577
  _globals['_TECHPROFILEDOWNLOADMESSAGE']._serialized_start=580
  _globals['_TECHPROFILEDOWNLOADMESSAGE']._serialized_end=814
  _globals['_DELETEGEMPORTMESSAGE']._serialized_start=816
  _globals['_DELETEGEMPORTMESSAGE']._serialized_end=920
  _globals['_DELETETCONTMESSAGE']._serialized_start=922
  _globals['_DELETETCONTMESSAGE']._serialized_end=1021
  _globals['_ONUINDICATIONMESSAGE']._serialized_start=1023
  _globals['_ONUINDICATIONMESSAGE']._serialized_end=1112
  _globals['_TECHPROFILEINSTANCEREQUESTMESSAGE']._serialized_start=1115
  _globals['_TECHPROFILEINSTANCEREQUESTMESSAGE']._serialized_end=1278
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/core.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18voltha_protos/core.proto\x12\x04\x63ore\"\x87\x02\n\x14\x44\x65viceTransientState\x12\x39\n\x0ftransient_state\x18\x01 \x01(\x0e\x32 .core.DeviceTransientState.Types\"\xb3\x01\n\x05Types\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41NY\x10\x01\x12\x12\n\x0e\x46ORCE_DELETING\x10\x02\x12\x19\n\x15\x44\x45LETING_FROM_ADAPTER\x10\x03\x12\"\n\x1e\x44\x45LETING_POST_ADAPTER_RESPONSE\x10\x04\x12\x11\n\rDELETE_FAILED\x10\x05\x12\x19\n\x15RECONCILE_IN_PROGRESS\x10\x06\x12\x16\n\x12REBOOT_IN_PROGRESS\x10\x07\x42H\n\x18org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'voltha_protos.core_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030org.opencord.voltha.coreZ,github.com/opencord/voltha-protos/v5/go/core'
  _globals['_DEVICETRANSIENTSTATE']._serialized_start=35
  _globals['_DEVICETRANSIENTSTATE']._serialized_end=298
  _globals['_DEVICETRANSIENTSTATE_TYPES']._serialized_start=119
  _globals['_DEVICETRANSIENTSTATE_TYPES']._serialized_end=298
# @@protoc_insertion_point(module_scope)
